;; basirgb.asm                                      letzte Aenderung: 18.7.2014
;* Variante fuer RGB-Ausgabe
;*
;* Schaltschema: basirgb.png
;*
;* Letzte Aenderungen:
;* 10.6.2014   Version 0.1, Erstellung aus basi.asm-1.3 und 1.4 zu kompliziert
;* 22.6.2014   Version 0.2, Erstellung aus testbild.asm	
;*
;* Copyright: Opensource, Freeware
;*
;* VERSION.REVISION = "0.3"
#define VERSION 0
#define REVISION 3
;*
;-----------------------------------------------------------------------------
;- Useroptionen:

.equ BAUDRATE=9600	  ;moegliche Werte: 9600, 19200, 38400, 57600

.equ RAND_LINKS=1900	  ;Linker Rand in Nanosekunden (Default 1800)
.equ RAND_OBEN=4	  ;Oberer Rand in Zeilen (optimale Einstellung abhaengig vom verwendeten Monitor
			  ;z.B. 2 fuer Analogfernseher, 12 fuer Digitalfernseher)
.set GRAFIK_ZEILEN=132	  ;bisher keine anderen Werte moeglich
.set GRAFIK_XPIXEL=192	  ;bisher keine anderen Werte moeglich

.equ HFARBE=0x40	  ;Hintergrund-Farbe (0x70=weiss, 0x00=schwarz, 0x10 rot, 0x20 gruen, 0x40 blau, 0x80=durchsichtig)
.equ TFARBE=0x70	  ;Text-Farbe oder Vordergrundfarbe

.equ ZEICHENSATZ6x8=1	  ;1=Latin1 (default), 2=myzeichensatz6x8.i (Fonttyp 1 und Groesse 6x8)
.equ ZEICHENSATZ12x16=1	  ;1=Chemiefont (default), 2=myzeichensatz12x16.i (Fonttyp 1 und Groesse 12x16)

.equ FONTGROESSE=6	  ;Moegliche Werte: 6, 12 (entspricht 6x8 und 12x16)
.equ TXTABSTANDX=0	  ;Abstand zwischen den Zeichen horizontal (bisher nur gradzahlige Werte erlaubt)
.equ TXTABSTANDY=1	  ;Abstand zwischen den Zeichen vertikal (maximal 4)
;; geht noch nicht:
.equ TXTGROESSE=2	  ;Vergroesserungsfaktor fuer Text

;#define INTERLACE	;fuer Interlace-Modus (noch nicht programmiert)

#define ATMEGA1284P	;geht nur mit diesem ohne zusaetzliches RAM
.equ F_CPU=20000000	;braucht immer 20 MHz

;- Ende Useroptionen
;-----------------------------------------------------------------------------
#define DEBUG		  ;zur Fehlersuche
#define WURZELTEST

.include "ifndeftest.inc"	;test damit man vor veraltetem avra gewarnt wird

#define MEDRES

.equ RAND_RECHTS=4000-RAND_LINKS	;Rechter Rand in Nanosekunden (Default 2200)
.equ oberedunkelzeilen=26 ;(von Monitor abhaengig? 26 fuer Analogfernseher, 36 fuer Digitalfernseher bei RAND_OBEN=2)

;; Eine normale Video-Zeile sieht so aus:
;; Schwarzschulter   Sync-Puls     Schwarzschulter, 
;; 1.5us (vordere)   4.7us HSync,  5.8us (hintere)   1.7us Rand links, 48us Text, 2.3us Rand rechts --> total 64us
;; 30 Takte          94 Takte      116 Takte         34 Takte          960 Takte  46      --> 1280 Takte bei 20MHz

.equ MU=F_CPU/1000000	;Ticks fuer 1 Microsekunde
.equ VORDERE_SCHWARZSCHULTER=MU*15/10
.equ SYNC1=MU*47/10		;4.7us fuer HSYNC, in Ticks
.equ SYNC2=140		;Anzahl Microsekunden fuer VSYNC-Puls mit Interlace (140-160, mind 132, max 180)
.equ SYNC3=160		;Anzahl Microsekunden fuer VSYNC-Puls ohne Interlace
.equ HINTERE_SCHWARZSCHULTER=12*MU-VORDERE_SCHWARZSCHULTER-SYNC1  ; Hinter = 12us - Vordere - Sync1
.equ RANDLINKS=RAND_LINKS*MU/1000	;Umrechnung von ns in Ticks (ergibt 36 bei Defaultwert)
.equ RANDRECHTS=RAND_RECHTS*MU/1000	;Umrechnung von ns in Ticks (ergibt 44 bei Defaultwert)
.equ INHALT=52*MU-RANDLINKS-RANDRECHTS	;Inhalt in horizontaler Richtung in Ticks (48us = 960 bei 20MHz)

#if INHALT!=(48*MU)
	.warning "INHALT ist ungleich 48 Microsekunden" ;test
#endif

.equ Z312=312
.equ zeilentotal=Z312
.equ INHALTZEILEN=264
.equ obereleerzeilen=oberedunkelzeilen+RAND_OBEN
.equ untereleerzeilen=zeilentotal-obereleerzeilen-INHALTZEILEN

.if untereleerzeilen<2
	.warning "Oberer Rand zu gross"
	.message "RAND_OBEN und Dunkelzeilen zusammen maximal 46"
.endif

;-----------------------------------------------------------------------------
;; Beginn des eigentlichen Codes

#ifdef ATMEGA328P
.include "m328Pdef.inc"		;ATmega328P
#endif
#ifdef ATMEGA1284P
.include "m1284Pdef.inc"	;ATmega1284P
#endif

	jmp main
.org OC1Aaddr
	jmp timer1_match_A

;-----------------------------------------------------------------------------
; Globale Registerbelegungen:
; r4=Sicherung von SREG im Interrupt
; r5=0  Global auf 0 gesetzt
; r6 = Zaehler fuer Moveto und Lineto
; r7 = Reserve
; r3:r2 = Zeiger ins Flash auf das Testbild
; r15 Widerhohlungszaehler fuer Videozeilen
.def zero=r5
.def movzaehler=r6
.def zeilenzaehlerL=r24
.def zeilenzaehlerH=r25
.def syncstatus=r8
#ifdef INTERLACE
.def halbbildflag=r9
.def mitteflag=r10
.def vsyncflag=r11
#endif
.def hintergrundfarbe=r22
.def textfarbe=r23
; Noch im Hauptprogramm verwendbar:
; r0-r1, r12-r14, r16-r21
; XH:XL (r27:r26)
; YH:YL (r29:r28)
; ZH:ZL (r31:r30)

;-----------------------------------------------------------------------------
; Registerbelegung im Hauptprogramm:
.def status=r19
.def altsec=r14

;-----------------------------------------------------------------------------
; Konstanten:
  .equ SYNC_PORT=PORTB
  .equ SYNC_DDR =DDRB
  .equ SYNCBIT=PB1
  .equ BILD_PORT=PORTA
  .equ BILD_DDR =DDRA
  .equ BILDBITR=PA4
  .equ BILDBITG=PA5
  .equ BILDBITB=PA6

#ifdef DEBUG
  .equ LED_PORT=PORTB
  .equ LED_DDR=DDRB
  .equ LED1=0
  .equ LED2=3
#endif

.equ SERBUFFERSIZE=64		;Fuer rs232-Empfang (nur Werte 2^n verwendbar)

;-----------------------------------------------------------------------------
; Macros:

.macro	ticksw
.endm
.macro	ticksw_i
  #if @0<0
	.warning "negativer Wert in macro ticksw"
  #endif
  #if @0==1
	nop
  #endif
  #if @0==2
	adiw r24,0
  #endif
  #if @0==3
	nop
	adiw r24,0
  #endif
  #if @0==4
	adiw r24,0
	adiw r24,0
  #endif
  #if @0==5
	nop
	adiw r24,0
	adiw r24,0
  #endif
  #if @0==6
	adiw r24,0
	adiw r24,0
	adiw r24,0
  #endif
  #if @0==7
	rcall tickswait7
  #endif
  #if @0==8
	rcall tickswait8
  #endif
  #if @0==9
	rcall tickswait9
  #endif
  #if @0==10
	rcall tickswait10
  #endif
  #if @0==11
	rcall tickswait11
  #endif
  #if @0==12
	rcall tickswait12
  #endif
  #if @0==13
	rcall tickswait13
  #endif
  #if @0==14
	rcall tickswait14
  #endif
  #if @0==15
	rcall tickswait15
  #endif
  #if @0==16
	rcall tickswait16
  #endif
  #if @0==17
	rcall tickswait17
  #endif
  #if @0>=18
	ldi r16, @0
	rcall tickswait
  #endif
.endm

.macro input
.endm
.macro input_8_i
#if @1>=64
	lds @0, @1
#else
	in  @0, @1
#endif
.endm

.macro output
.endm
.macro output_i_8
#if @0>=64
	sts @0, @1
#else
	out @0, @1
#endif
.endm

.equ MINA=14	;dies entspricht der minimalen Anzahl Takte bis TCNT1L eingelesen wird
.equ MAXA=20	;Maximaler Wert (6 mehr als MINA bei Verwendung von sleep, sonst sollte 4 reichen)

.macro jitterausgleich
	lds ZL, TCNT1L		;2 Takte
#ifdef JITTER_MINMAXTEST
	cp ZL, minwert
	brcc ji1
	mov minwert, ZL		;Minimalwert speichern
  ji1:	cp ZL, maxwert
	brcs ji2
	mov maxwert, ZL		;Maximalwert speichern
  ji2:
#endif
	clr  ZH
	cpi ZL, MAXA+1		;TCNT1 doch groesser als Maximaler Zaehlerstand
	brcc fehler		;ja--> Absturz verhindern
	subi ZL, low(-(L1-MINA))  ;16-Bit-Addition von (L1-Minimum)
	sbci ZH, high(-(L1-MINA)) ;also Z = L1 + Zaehlerstand-Minimum
	ijmp
fehler:
#ifdef DEBUG
	sbi LED_PORT, LED2	;Fehlertest
#endif
	nop
	nop
	nop
	nop	;zusaetzliche nop falls TCNT1 doch kleiner als MINA ist
#ifdef DEBUG
	sbi LED_PORT, LED1	;Fehlertest
#endif
L1:	nop	;bis zu 6 Takte fuer Jitterausgleich
	nop
	nop
	nop
	nop
	nop
	; 9 bis 15 Takte gebraucht (6 mehr mit MINMAXTEST)
	;; hier sollte es jitterfrei sein.
.endm

#ifdef JITTER_MINMAXTEST
.set JITAKTE=21
#else
.set JITAKTE=15
#endif
	
;-----------------------------------------------------------------------------
; Variablen im SRAM:
                .DSEG
serbuffer:	.BYTE SERBUFFERSIZE
jread:		.BYTE 1			; wenn jread==jwrite dann ist der Buffer leer
jwrite:		.BYTE 1			; wenn jread==jwrite+1 dann ist der Buffer voll
uhr_ticks64:	.BYTE 1		; Zaehler in 8us Einheiten (0,8,16...>125) alle 64us aktualisiert
uhr_millisecL:	.BYTE 1
uhr_millisecH:	.BYTE 1
uhr_sec:	.BYTE 1		; Zeit seit dem Einschalten
uhr_min:	.BYTE 1
uhr_std:	.BYTE 1
uhr_tage:	.BYTE 1
pieps_endzeit:	.BYTE 1		; Endzeit+1 fuer Piepser in 4-Millisekunden-Schritten
xcursorL:	.BYTE 1
xcursorH:	.BYTE 1
ycursorL:	.BYTE 1
ycursorH:	.BYTE 1
xcursor2L:	.BYTE 1
xcursor2H:	.BYTE 1
ycursor2L:	.BYTE 1
ycursor2H:	.BYTE 1
txt_spalte:	.BYTE 1
txt_zeile:	.BYTE 1
fontbreite:	.BYTE 1
fonthoehe:	.BYTE 1
bildspeicher:	.BYTE GRAFIK_XPIXEL/2*GRAFIK_ZEILEN
stack:		.BYTE 64	; mindestens so viel fuer Unterprogrammaufrufe benoetigt (geschaetzt)
		.CSEG

;-----------------------------------------------------------------------------
;; Testbild im FLASH:
;; Bild mit kleinerer Aufloesung: 192 breit, 132 hoch
;; Bild mit groesserer Aufloesung: 240 breit, 264 hoch
testbild:
#ifdef MEDRES

;; Bild mit mittlerer Aufloesung: 192 breit, 132 hoch
;; 1. Zeile:
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	;erste 10 Bytes = 20 Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 40. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 60. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 80. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 100. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 120. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 140. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 160. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 180. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF			;181.-192. Pixel, weiss
;; 2. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, erstes Pixel weiss, rest schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db 0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz, letztes Pixel weiss
;; 3. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 4. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 5. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 6. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 7. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 8. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 9. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 10. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 11.-20. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 12. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 13. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 14. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 15. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 16. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 17. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 18. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 19. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 20. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 21.-40. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 2. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 3. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 4. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 5. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 6. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 7. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 8. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 9. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 10. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 11.-20. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 12. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 13. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 14. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 15. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 16. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 17. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 18. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 19. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 40. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 21.-40. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 2. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 3. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 4. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 5. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 6. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 7. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 8. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 9. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 50. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 11.-20. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 12. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 13. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 14. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 15. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 16. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 17. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 18. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 19. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 60. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 21.-40. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 2. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 3. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 4. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 5. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 6. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 7. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 8. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 9. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 50. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 11.-20. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 12. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 13. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 14. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 15. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 16. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 17. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 18. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 19. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 80. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 21.-40. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 2. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 3. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 4. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 5. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 6. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 7. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 8. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 9. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 90. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 11.-20. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 12. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 13. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 14. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 15. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 16. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 17. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 18. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 19. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 100.
;; 80. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 21.-40. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 2. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 3. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 4. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 5. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 6. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 7. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 8. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 9. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 90. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 11.-20. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 12. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 13. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 14. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 15. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 16. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 17. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 18. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 19. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 120. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 121. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 122. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 123. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 124. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 125. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 126. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 127. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 128. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 129. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 130. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 131. Zeile:
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-60. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-80. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-100. Pixel, weiss
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-120. Pixel, gelb
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-140. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-160. Pixel, rotblau
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-180. Pixel, grau
.db  0x00,0x00,0x00,0x00,0x00,0x0F			;181.-192. Pixel, schwarz
;; 132. Zeile:					
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	;erste 10 Bytes = 20 Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 40. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 60. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 80. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 100. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 120. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 140. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 160. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	; - 180. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF			;181.-192. Pixel, weiss

#else

;; Bild mit groesserer Aufloesung: 240 breit, 264 hoch
;; 1. Zeile:					
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;erste 10 Bytes = 20 Pixel, schwarz
.db 0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x11	;21.-40. Pixel, rot
.db 0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33,0x33	;21.-60. Pixel, gelb
.db 0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22,0x22	;41.-80. Pixel, gruen
.db 0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x44	;61.-100. Pixel, blau
.db 0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77,0x77	;21.-120. Pixel, weiss
.db 0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70	;21.-140. Pixel, grau
.db 0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55,0x55	;21.-160. Pixel, cyan
.db 0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66,0x66	;21.-180. Pixel, rotblau
.db 0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	;181.-200. Pixel, schwarz
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	;181.-220. Pixel, weiss
.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF	;181.-240. Pixel, weiss
;; da muessten noch mehr Zeilen kommen

#endif

;-----------------------------------------------------------------------------
;; Zeichensaetze im FLASH:

font6x8:
#if ZEICHENSATZ6x8==2
.include "myzeichensatz6x8.i"
#else
.include "isolatin1.i"
#endif

font12x16:
#if ZEICHENSATZ12x16==2
.include "myzeichensatz12x16.i"
#else
.include "chemiefont.i"
#endif

.equ CR=0x0D
.equ LF=0x0A

starttext:
;	.db "Basirgb.asm ",'0'+VERSION,'.','0'+REVISION,0
	.db "Basirgb.asm ",0,0
startt1: .db "Basi",0,0		;test
startt2: .db ".asm ",0		;test
starttext_version:
	.db '0'+VERSION,'.','0'+REVISION,0
beispieltext:
	.db "Autor: Rolf Pfister",LF
	.db "Copyr: Freeware OpenSource",LF,0
beispieltext2:
	.db "www.rolfp.ch/elektronik/",LF,0
baud:
	.db "Baudrate: "
.if BAUDRATE==9600
	.db "9600 ",LF
.elif BAUDRATE==19200
	.db "19200",LF
.elif BAUDRATE==38400
	.db "38400",LF
.elif BAUDRATE==57600
	.db "57600",LF
.endif
	.db 0,0

;-----------------------------------------------------------------------------
testbild_ins_ram_kopieren:	;zerstoerte Register: r16, X, Z
	push r24		;muss vor dem Einschalten der Interrupts gemacht werden
	push r25
	ldi r24, low(GRAFIK_ZEILEN*GRAFIK_XPIXEL/2)
	ldi r25, high(GRAFIK_ZEILEN*GRAFIK_XPIXEL/2)
	ldi ZL, low(testbild<<1)
	ldi ZH, high(testbild<<1)
	ldi XL, low(bildspeicher)
	ldi XH, high(bildspeicher)
_L1:	lpm r16, Z+
	st X+, r16
	sbiw r24, 1
	brne _L1
	pop r25
	pop r24
	ret

screenclear:
	push r26		;entspricht XL
	push r27		;entspricht XH
	push YL
	push YH
	ldi r26, low(GRAFIK_ZEILEN*GRAFIK_XPIXEL/2)
	ldi r27, high(GRAFIK_ZEILEN*GRAFIK_XPIXEL/2)
	ldi YL, low(bildspeicher)
	ldi YH, high(bildspeicher)
	mov r16, hintergrundfarbe
	swap r16
	or  r16, hintergrundfarbe
_L1:	st Y+, r16
	sbiw r26, 1
	brne _L1
	pop YH
	pop YL
	pop r27
	pop r26
	ret

beispieltexte_darstellen:	;zerstoerte Register: r16, Z
;	ldi ZL, low(starttext<<1)
;	ldi ZH, high(starttext<<1)
	ldi ZL, low(startt1<<1)
	ldi ZH, high(startt1<<1)
	ldi hintergrundfarbe, 0x80  ;test: durchsichtig
	ldi r16, 12		    ;test: grosser Font
	sts fontbreite, r16
	ldi r16, 16
	sts fonthoehe, r16
	rcall text_darstellen
	ldi textfarbe, 0x10  ;Roter Text
	ldi r16, 'r'
	rcall text_zeichnen
	ldi textfarbe, 0x20  ;Gruener Text
	ldi r16, 'g'
	rcall text_zeichnen
	ldi textfarbe, 0x40  ;Blauer Text
	ldi r16, 'b'
	rcall text_zeichnen
	ldi textfarbe, TFARBE	    ;wieder voreingestellte Textfarbe
	ldi ZL, low(startt2<<1)
	ldi ZH, high(startt2<<1)
	ldi hintergrundfarbe, 0x80  ;test: durchsichtig
	rcall text_darstellen
	ldi ZL, low(starttext_version<<1)
	ldi ZH, high(starttext_version<<1)
	ldi hintergrundfarbe, HFARBE
	rcall text_darstellen
	ldi r16, FONTGROESSE		;restlicher Beispieltext in vorgegebener Groesse
	sts fontbreite, r16
	ldi r16, FONTGROESSE*4/3	;restlicher Beispieltext in vorgegebener Groesse
	sts fonthoehe, r16
	ldi r16, 4
	sts txt_zeile, r16		;auf 5.Zeile beginnen
	ldi r16, 0
	sts txt_spalte, r16		;auf 1.Spalte beginnen
	ldi ZL, low(beispieltext<<1)
	ldi ZH, high(beispieltext<<1)
	rcall text_darstellen
	ldi ZL, low(beispieltext2<<1)
	ldi ZH, high(beispieltext2<<1)
	rcall text_darstellen
	ldi ZL, low(baud<<1)
	ldi ZH, high(baud<<1)
	rcall text_darstellen
	ret

td_L1:	rcall text_print
text_darstellen:		;Text ab ZH:ZL vom Flash einlesen und darstellen
	lpm r16, Z+
	tst r16
	brne td_L1
	ret
	
;-----------------------------------------------------------------------------
.equ NormalerCompwert = (F_CPU*64/1000000)-1	 ;64 usec fuer Zeilenlaenge

#ifdef INTERLACE

#else

timer1_init:			;fuer Variante ohne Interlace
	ldi r16, (1<<WGM12)|(1<<CS10)	;CTC-OCR1A-Modus, Prescaler=1
	sts TCCR1B, r16			;beim Atmega1284P muss fuer einige io-Register sts statt out verwendet werden
	ldi r16, low(NormalerCompwert)
	ldi r17, high(NormalerCompwert)
	sts OCR1AH, r17
	sts OCR1AL, r16
	ldi r16, 0		;Startwert des Timers = 0
	sts TCNT1H, r16
	sts TCNT1L, r16
	ldi r16, (1<<OCIE1A)	;Timer1 Interrupts bei Vergleichswert
	sts TIMSK1, r16
	ldi zeilenzaehlerL, low(Z312-1)
	ldi zeilenzaehlerH, high(Z312-1) ;Starten mit letzter Zeile
	clr syncstatus
#ifdef HIRES
	ldi r16, 1		;nicht wirklich benoetigt bei HIRES
#else
	ldi r16, 2		;jeweils 2 Videozeilen gleich (bei LOWRES und MEDRES)
#endif
	mov r15, r16
	ret

#endif

;; Eine normale Video-Zeile sieht so aus:
;; Schwarzschulter   Sync-Puls     Schwarzschulter,
;; 1.5us (vordere)   4.7us HSync,  5.8us (hintere)   1.8us Rand links, 48us Text, 2.2us Rand rechts --> total 64us
;; 30 Takte          94 Takte      116 Takte         36 Takte          960 Takte  44      --> 1280 Takte bei 20MHz

#ifdef INTERLACE

#else

timer1_match_A:			;Interrupt-Routine, Variante ohne INTERLACE
	out BILD_PORT, zero	;vordere Schwarzschulter 1.5us
	in r4, SREG
	push ZL
	push ZH
	jitterausgleich
	push r19
	push r16
	push r17
	push r18
	ticksw [VORDERE_SCHWARZSCHULTER-15-JITAKTE] ;Ticks von "in r4" bis und mit "cbi SYNC"
	cbi SYNC_PORT, SYNCBIT		;Synchronisationspuls starten (HSYNC oder VSYNC)
	adiw zeilenzaehlerL, 1
	tst syncstatus			;ist gesetzt wenn VSYNC ausgefuehrt wird
	brne t1_L2
	ldi r16, high(Z312)
	cpi zeilenzaehlerL, low(Z312)	;letzte Videozeile erreicht?
	cpc zeilenzaehlerH, r16		;7 Takte bis hier
	breq vsync_start
	clr r17			;r17 auf schwarz setzen
	ldi r16, high(oberedunkelzeilen)
	cpi zeilenzaehlerL, low(oberedunkelzeilen)
	cpc zeilenzaehlerH, r16		;12 Takte bis hier
	brcs leerzeile_1
	mov r17, hintergrundfarbe
	ldi r16, high(oberedunkelzeilen+RAND_OBEN)
	cpi zeilenzaehlerL, low(oberedunkelzeilen+RAND_OBEN)
	cpc zeilenzaehlerH, r16		;17 Takte bis hier
	brcs leerzeile_farbe_r17
	ldi r16, high(oberedunkelzeilen+RAND_OBEN+INHALTZEILEN)
	cpi zeilenzaehlerL, low(oberedunkelzeilen+RAND_OBEN+INHALTZEILEN)
	cpc zeilenzaehlerH, r16		;21 Takte bis hier
	brcs normale_zeile		;--> normale Videozeile darstellen (mit Bildinhalt)
	rjmp leerzeilen_unten
leerzeile_1:			;14 Takte bis hier
	ticksw [5]
leerzeile_farbe_r17:		;19 Takte bis hier
	ticksw [5]
leerzeilen_unten:		;24 Takte bis hier
	rcall uart_check	;+45 Takte
	ticksw [SYNC1-24-45-2]	;SYNC1 - Takte bis hier - 2 fuer sbi
	sbi SYNC_PORT, SYNCBIT	;HSYNC Synchronisationspuls ende
	out BILD_PORT, r17
uhr_t1_ret:			;Zeit schnell aktualisieren dann return
	rcall uhr_update64_schnell
	rjmp t1_ret
vsync_start:
	ldi zeilenzaehlerL, 0		;Zeilenzaehler wieder auf Anfang, und VSYNC gestartet
	ldi zeilenzaehlerH, 0
	ldi ZL, low(bildspeicher)
	ldi ZH, high(bildspeicher)
	movw r2, ZL
	ldi r16, 2		;Statt hier 160 usec zu vertroedeln, 2 Interrupts abwarten und nur noch
	mov syncstatus, r16	;beim 3. mal die restlichen 160-2*64=32 usec abwarten
	rjmp uhr_t1_ret
t1_L2:				;5 Takte bis hier
	dec syncstatus
	brne uhr_t1_ret
	rcall uhr_update64	;+61 Takte
	ticksw [4*MU-68]	;4 Microsekunden bis hier
	ldi r16, SYNC3-2*64-4	;32 - Anzahl schon verbrauchte Microsekunden bis hier
	rcall usecwait		;160 Microsekunden fuer Seitensynchronisation (2*64+32)
	sbi SYNC_PORT, SYNCBIT	;VSYNC Synchronisationspuls ende
t1_ret:
	pop r18
	pop r17
	pop r16
	pop r19
	pop ZH
	pop ZL
	out SREG, r4
	reti
normale_zeile:			;23 Takte bis hier
;	rcall tickswait7	;Pause damit Verzoegerung gleich lang wie in Interlace-Variante
videozeile_darstellen:
	movw ZL, r2		;24 Takte bis hier
	rcall uart_check	;+45 Takte
	ticksw [SYNC1-24-45-2]
	sbi SYNC_PORT, SYNCBIT	;HSYNC Synchronisationspuls ende
	rcall uhr_update64	;61 Takte
	ticksw [HINTERE_SCHWARZSCHULTER-61]
	out BILD_PORT, hintergrundfarbe
	ticksw [RANDLINKS-8]	;Anzahl Takte bis zum ersten Bit abziehen

#ifdef MEDRES
	ldi r16, low(GRAFIK_XPIXEL/2)
	rjmp _L1
_L0:	out BILD_PORT, r19
_L1:	ld r19, Z+		;2 Takte
	nop			;1
	nop			;1
	out BILD_PORT, r19	;1 --> zusammen 5
	swap r19		;1
	dec r16			;1
	brne _L0		;2 Takte --> zusammen mit out bei _L0: 5 Takte pro Pixel
	nop
	out BILD_PORT, r19	;1 Takt
	dec r15			;wird Widerhohlungszaehler gleich Null?
	brne _nochmals		;nein: gleiche Zeile nochmals
	ldi r16, 2
	mov r15, r16		;jeweils 2 Zeilen gleich
	out BILD_PORT, hintergrundfarbe
	rjmp _L3
_nochmals:
	movw ZL, r2
	out BILD_PORT, hintergrundfarbe
_L3:	movw r2, ZL
	pop r18
	pop r17
#endif ;//MEDRES

	pop r16
	pop r19
	pop ZH
	pop ZL
	out SREG, r4
	reti

#endif ;//INTERLACE

;-----------------------------------------------------------------------------
; Hauptprogramm:
main:	ldi r16, low(RAMEND)
        out SPL, r16		; Init Stackpointer L
        ldi r16, high(RAMEND)
        out SPH, r16		; Init Stackpointer H
	clr zero		; r5 global mit 0 belegen
	ldi r16, (1<<BILDBITR)|(1<<BILDBITG)|(1<<BILDBITB)
	out BILD_DDR, r16	; Ausgang fuer Bildinhalt
	ldi r16, (1<<SYNCBIT)	; z.B. PC0
	out SYNC_DDR, r16	; Ausgang fuer Synchronisations-Pulse
	out SYNC_PORT, r16	; Ausgang gesetzt fuer inaktiv
	ldi hintergrundfarbe, HFARBE
	ldi textfarbe, TFARBE
	ldi r16, FONTGROESSE
	sts fontbreite, r16
	ldi r16, FONTGROESSE*4/3
	sts fonthoehe, r16
	ldi r16, 1		;provi. Startposition fuer Text: 2. Zeile
	sts txt_zeile, r16
	ldi r16, 1		;provi. Startposition fuer Text: 2. Spalte
	sts txt_spalte, r16
	sts xcursorL, zero
	sts xcursorH, zero
	sts ycursorL, zero
	sts ycursorH, zero
#ifdef DEBUG
	sbi LED_DDR, LED1
	sbi LED_DDR, LED2
	sbi LED_PORT, LED1	;LED1 an
	sbi LED_PORT, LED2	;LED2 an
#endif
	rcall testbild_ins_ram_kopieren
	rcall beispieltexte_darstellen
	rcall uhr_reset
	clr altsec
	clr movzaehler
	rcall uart_init
	rcall timer1_init
	sei			; Interrupts einschalten

;; Initialisierungen fuers Hauptprogramm:
	ldi status, 4		;r19=status, 4=Startmodus

	ldi r16, (1<<SE)	;Schlafmodus IDLE setzen
	out SMCR, r16
#ifdef DEBUG
_L1:	sleep
	lds r16, uhr_sec
	cp r16, altsec
	breq _L1		;erste Sekunde abwarten
	mov altsec, r16
	cbi LED_PORT, LED1	;LED1 aus
	cbi LED_PORT, LED2	;LED2 aus
#endif
mainloop:
	sleep			;nicht unbedingt noetig, koennte aber etwas Strom sparen
#ifdef DEBUG
	cpi status, 4
	brne ma_uartcheck
	lds r16, uhr_sec
	cp r16, altsec
	breq mainloop		;naechste Sekunde abwarten
;	cbi LED_PORT, LED1	;LED1 aus
;	cbi LED_PORT, LED2	;LED2 aus
	mov altsec, r16
	ldi r16, 8		;Zeit auf 9.Zeile
	sts txt_zeile, r16
	ldi r16, 1		;auf 2.Spalte beginnend
	sts txt_spalte, r16
	lds r16, uhr_std
	rcall zahl2stellig
	ldi r16, ':'
	rcall text_zeichnen
	lds r16, uhr_min
	rcall zahl2stellig
	ldi r16, ':'
	rcall text_zeichnen
	lds r16, uhr_sec
	rcall zahl2stellig
#ifdef WURZELTEST
	lds r16, uhr_sec
	cpi r16, 0
	brne _w2
	lds r16, uhr_min
	cpi r16, 1
	brne _w2
	rcall teste_wurzel_varianten
_w2:	
#endif
ma_uartcheck:
#endif
	lds r17, jwrite
	lds r18, jread
	cp r18, r17		;neues Zeichen von UART-Empfang vorhanden?
	breq mainloop		;nein-->
	ldi XL, low(serbuffer)
	ldi XH, high(serbuffer)
	add XL, r18
	adc XH, zero
	ld r16, X		;Empfangenes Zeichen vom Puffer einlesen
	inc r18
	andi r18, SERBUFFERSIZE-1
	sts jread, r18		;aktualisierter Lesezeiger speichern
	tst status
	brne ma_status_auswerten
ma_L0:	cpi r16, 0x20
	brcs ma_steuerzeichen
ma_L1:	rcall text_zeichnen	;empfangenes Zeichen an aktueller Position zeichnen
	rjmp mainloop
ma_screenclear2:
	rcall screenclear	;Seite loeschen ohne Textcursor zu veraendern
	rjmp mainloop
ma_screenclear:
	rcall screenclear	;Seite loeschen und Textcursor nach oben links setzen
ma_newpage:
	clr r16
	sts txt_zeile, r16
	sts txt_spalte, r16	
	rjmp mainloop
ma_steuerzeichen:
	cpi r16, 0x0A		;Sonderzeichen LF?
	breq ma_einezeilerunter
	cpi r16, 0x0D		;Sonderzeichen CR?
	brne ma_s1
	clr r16
	sts txt_spalte, r16	;auf Zeilenanfang setzen
	rjmp mainloop
ma_s1:
	cpi r16, 0x08		;Sonderzeichen Bachspace?
	breq ma_backspace
	cpi r16, 0x07		;Sonderzeichen fuer Piepston?
#ifdef PIEPSOFF
	breq mainloop		;ja --> ignorieren
#else
	breq ma_pi1		;ja --> Piepston starten
#endif
	cpi r16, 0x0C		;Sonderzeichen Newpage?
	breq ma_newpage
#ifdef MITESCSEQUENZEN
	cpi r16, 0x1B		;Sonderzeichen ESC
	breq ma_status_setzen
#endif
	cpi r16, 4		;Steuerzeichen fuer Seite loeschen?
	breq ma_screenclear
	cpi r16, 0
	breq ma_L1		;als normales Zeichen behandeln
	cpi r16, 7		;Restliche Steuerzeichen von 1 bis 6?
	brcs ma_status_setzen	;ja--> (1=Sonderz. 2=Zeilenwahl, 3=Spaltenwahl, 5=Hexmodus, 6=Zeichengroesse)
	cpi r16, 0x10		;Steuerzeichen im Bereich 0x10 bis 0x19 ?
	brcs ma_L1		;nein--> normales Zeichen
	cpi r16, 0x19		;Steuerzeichen fuer Screenclear2 ?
	breq ma_screenclear2	;ja--> (0x19=Screenclear2)
	cpi r16, 0x1A+1		;Steuerzeichen im Bereich 0x10 bis 0x1A ?
	brcc ma_L1		;nein: alle andern Zeichen als normale Zeichen behandeln
;	brcs ma_status_setzen	;ja--> (0x10, 0x11=Farben setzen, 0x12=Moveto 0x13=Lineto ... 0x18=Fillcircle)
ma_status_setzen:
	mov status, r16
	rjmp mainloop
ma_status_auswerten:
	dec status		;war status==1 ?
	breq ma_L1		;ja: status geloescht und Sprung zum Zeichen als normales Zeichen behandeln
	inc status
#ifdef VERALTETE_VERSION
	cpi status, 2
	breq ma_neuezeile
	cpi status, 3
	breq ma_neuespalte
	cpi status, 4		;waren wir noch im Startmodus?
	breq ma_startmodus_aus	;ja-->
	cpi status, 6		;Zeichengroesse aendern?
	breq ma_zeichengroesse	;ja-->
	cpi status, 0x10	;Farbe aendern?
	breq ma_hintergrundfarbe
	cpi status, 0x11	;Farbe aendern?
	breq ma_vordergrundfarbe
	cpi status, 0x12	;Moveto?
	breq ma_moveto
	cpi status, 0x13	;Lineto?
	breq ma_lineto
	cpi status, 0x14	;Punkt Zeichnen?
	breq ma_punkt
#endif
; 0x02: Zeilenauswahl     Nachfolgendes Zeichen ist Zeilennummer
; 0x03: Spaltenauswahl    Nachfolgendes Zeichen ist Spaltennummer
; 0x04: Seite loeschen    Seite loeschen und Cursor nach links oben setzen
; 0x05: Hexmodus ein/aus  Alle Zeichen als Hexzahlen anzeigen (z.B. '41 ' fuer A)
; 0x06: Zeichengroesse    Nachfolgendes Zeichen ist Zeichenbreite (nur 6 oder 12 erlaubt)
; 0x10: Hintergrundfarbe  Nachfolgendes Zeichen ist Farbe, Werte 0 bis 8 erlaubt
; 0x11: Vordergrundfarbe  Nachfolgendes Zeichen ist Farbe, (1=rot, 2=gruen, 4=blau, 8=durchsichtig)
; 0x12: Moveto    Position setzen: 2 Zeichen fuer Spalte, 2 Zeichen fuer Zeile, jeweils erst Low dann High
; 0x13: Lineto    neue Position setzen und Linie zeichnen
; 0x14: Punkt zeichnen    An aktueller Position einen Punkt zeichnen, nachfolgendes Zeichen ist Farbe
; 0x15: Drawbox   Viereck zeichnen (neue Position wie bei Lineto)
; 0x16: Fillbox   Gefuelltes Viereck zeichnen (neue Position wie bei Lineto)
; 0x17: Drawcircle  Kreis zeichnen an aktueller Position, nachfolgende 4 Zeichen ist x- und y-Durchmesser
; 0x18: Fillcircle  Gefuellter Kreis zeichnen an aktueller Position, nachfolgende 4 Zeichen ist x- und y-Durchmesser
; 0x19: Seite loeschen    Seite mit Hintergrundfarbe fuellen, Cursor unveraendert
; 0x1A: Echo  Naechstes Zeichen zuruecksenden (zum Uebertragung testen)
; 0x1B..0x1D fuer ESC-Sequenzen vorgesehen
	cpi status, 0x1E
	brcc ma_hexmodus	;bei unbekanntem Code --> hexmodus
	ldi ZL, low(sprungtabelle)
	ldi ZH, high(sprungtabelle)
	add ZL, status
	adc ZH, zero
	ijmp
ma_escape:			;provi. noch keine ESC-Sequenzen unterstuetzt
ma_escape1:			;provi. noch keine ESC-Sequenzen unterstuetzt
ma_escape2:			;provi. noch keine ESC-Sequenzen unterstuetzt
ma_hexmodus:
	cpi r16, 5		;Steuerzeichen fuer Hexmodus?
	breq ma_L2		;ja--> Hexmodus wieder ausschalten
	mov r18, r16
	swap r16		;obere 4 Bits nach unten,
	rcall hexdigit		;in eine Zahl ('0'...'F') wandeln
	rcall text_zeichnen
	mov r16, r18
	rcall hexdigit		;gleiches fuer untere 4 Bits
	rcall text_zeichnen
	ldi r16, ' '		;zwischen den 2-stelligen Hexzahlen jeweils eine Leerstelle
	rcall text_zeichnen
	rjmp mainloop
ma_backspace:
	rcall backspace
	rjmp mainloop
ma_pi1:	rcall piepston_starten
	rjmp mainloop
ma_einezeilerunter:
	rcall einezeilerunter
	rjmp mainloop
ma_neuespalte:
	rcall neuespalte
ma_L2:	clr status
	rjmp mainloop
ma_neuezeile:
	rcall neuezeile
	rjmp ma_L2
ma_startmodus_aus:
	clr status
	rjmp ma_L0

ma_zeichengroesse:
	lds r18, fontbreite
	cp r16, r18		;schon diese Groesse gesetzt?
	breq ma_L2		;ja--> nichts zu tun
	ldi r17, 8
	cpi r16, 6
	breq _L1
	ldi r17, 16
	cpi r16, 12
	brne ma_L2		;ungueltige Zeichengroesse ignorieren
_L1:	rcall zeichengroesse_setzen
	rjmp ma_L2		;status loeschen und Sprung zum mainloop
ma_hintergrundfarbe:
	cpi r16, 0x10		;Farbe in oberer Bytehaelfte?
	brcc _L1
	swap r16		;nein: in obere Bytehaelfte verschieben
_L1:	andi r16, 0xF0		;sicherstellen dass nur Bits in oberer Haelfte gesetzt sind
	mov hintergrundfarbe, r16
	rjmp ma_L2		;status loeschen und Sprung zum mainloop
ma_vordergrundfarbe:
	cpi r16, 0x10		;Farbe in oberer Bytehaelfte?
	brcc _L1
	swap r16		;nein: in obere Bytehaelfte verschieben
_L1:	andi r16, 0xF0		;sicherstellen dass nur Bits in oberer Haelfte gesetzt sind
	mov textfarbe, r16
	rjmp ma_L2		;status loeschen und Sprung zum mainloop
ma_moveto:
	rcall cursor_setzen	;letztes Byte?
	breq ma_L2		;ja--> Status loeschen, dann zum mainloop
	rjmp mainloop		;nein--> direkt zum mainloop
ma_lineto:	
	rcall cursor_setzen2	;letztes Byte?
	breq ma_L3		;ja-->
	rjmp mainloop		;nein--> direkt zum mainloop
ma_L3:	rcall linie_zeichnen
	rjmp ma_L2
ma_punkt:
	rcall punkt_setzen
	rjmp ma_L2
ma_drawbox:
	rcall cursor_setzen2	;letztes Byte?
	breq ma_L4		;ja-->
	rjmp mainloop		;nein--> direkt zum mainloop
ma_L4:	clr r17
	rcall viereck_zeichnen
	rjmp ma_L2
ma_fillbox:
	rcall cursor_setzen2	;letztes Byte?
	breq ma_L5		;ja-->
	rjmp mainloop		;nein--> direkt zum mainloop
ma_L5:	ldi r17, 1
	rcall viereck_zeichnen
	rjmp ma_L2
ma_fillcircle:
	ldi r18, 1
	rjmp ma_L6
ma_drawcircle:
	ldi r18, 0
ma_L6:	rcall cursor_setzen2	;letztes Byte?
	breq ma_L7		;ja-->
	rjmp mainloop		;nein--> direkt zum mainloop
ma_L7:	mov r17, r18
	rcall kreis_zeichnen	;r17=Fuellflag, xcursor2=Radiusx, ycursor2=Radiusy
	rjmp ma_L2
ma_echo:			;Zeichen zuruecksenden
	cpi r16, 0x1A		;Echo-Zeichen ?
	brne _L1
	rjmp ma_L2		;ja: Echo wieder ausschalten
_L1:	rcall uart_putc
	rjmp mainloop

sprungtabelle:
	rjmp ma_hexmodus	;0x00 bei unerwartetem Code --> hexmodus
	rjmp ma_hexmodus	;0x01 bei unerwartetem Code --> hexmodus
	rjmp ma_neuezeile	;0x02
	rjmp ma_neuespalte	;0x03
	rjmp ma_startmodus_aus	;0x04 waren wir noch im Startmodus?
	rjmp ma_hexmodus	;0x05 hexmodus
	rjmp ma_zeichengroesse	;0x06
	rjmp ma_hexmodus	;0x07 bei unerwartetem Code --> hexmodus
	rjmp ma_hexmodus	;0x08 bei unerwartetem Code --> hexmodus
	rjmp ma_hexmodus	;0x09 bei unerwartetem Code --> hexmodus
	rjmp ma_hexmodus	;0x0A bei unerwartetem Code --> hexmodus
	rjmp ma_hexmodus	;0x0B bei unerwartetem Code --> hexmodus
	rjmp ma_hexmodus	;0x0C bei unerwartetem Code --> hexmodus
	rjmp ma_hexmodus	;0x0D bei unerwartetem Code --> hexmodus
	rjmp ma_hexmodus	;0x0E bei unerwartetem Code --> hexmodus
	rjmp ma_hexmodus	;0x0F bei unerwartetem Code --> hexmodus
	rjmp ma_hintergrundfarbe ;0x10
	rjmp ma_vordergrundfarbe ;0x11
	rjmp ma_moveto		;0x12
	rjmp ma_lineto		;0x13 Linie zeichnen
	rjmp ma_punkt		;0x14 Punkt zeichnen
	rjmp ma_drawbox		;0x15
	rjmp ma_fillbox		;0x16
	rjmp ma_drawcircle	;0x17
	rjmp ma_fillcircle	;0x18
	rjmp ma_screenclear2	;0x19
	rjmp ma_echo		;0x1A Echo, naechstes Zeichen zuruecksenden
	rjmp ma_escape		;0x1B
	rjmp ma_escape1		;0x1C
	rjmp ma_escape2		;0x1D
;	rjmp ma_hexmodus	;0x1E bei unerwartetem Code --> hexmodus
;	rjmp ma_hexmodus	;0x1F bei unerwartetem Code --> hexmodus

cursor_setzen2:
	push XL
	push XH
	ldi XL, low(xcursor2L)
	ldi XH, high(xcursor2L)
	rjmp cu_L1
cursor_setzen:
	push XL
	push XH
	ldi XL, low(xcursorL)
	ldi XH, high(xcursorL)
cu_L1:	ldi r17, 4		;total 4 Bytes speichern
	tst movzaehler
	brne cu_L2
	mov movzaehler, r17
	rjmp cu_L3
cu_L2:	sub r17, movzaehler
	add XL, r17
	adc XH, zero
cu_L3:	st X, r16
	dec movzaehler
	pop XH
	pop XL
	ret

einezeilerunter:	
	ldi r17, GRAFIK_ZEILEN/(8+TXTABSTANDY)	
	lds r16, fontbreite
	cpi r16, 12
	brne _e1
	ldi r17, GRAFIK_ZEILEN/(16+TXTABSTANDY)	
_e1:	lds r16, txt_zeile
	inc r16
	cp  r16, r17
	brcs _e2
	clr r16			;nach letzter Zeile wieder oben beginnend
_e2:	sts txt_zeile, r16
	ret

neuezeile:			;r16=neue Zeile, Nummerierung bei 0 beginnend, r16,r17 zerstoert
	lds r17, fontbreite
	cpi r17, 12
	ldi r17, GRAFIK_ZEILEN/(8+TXTABSTANDY)	
	brne _L1
	ldi r17, GRAFIK_ZEILEN/(16+TXTABSTANDY)	
_L1:	cp  r16, r17		;maximale Zeilenzahl ueberschritten?
	brcs _L2		;nein-->
	mov r16, r17
	dec r16			;ja: auf letzte Zeile setzen
_L2:	sts txt_zeile, r16
	ret

neuespalte:			;r16=neue Spalte, Nummerierung bei 0 beginnend, r16,r17 zerstoert
	lds r17, fontbreite
	cpi r17, 12
	ldi r17, GRAFIK_XPIXEL/(6+TXTABSTANDX)
	brne _L1
	ldi r17, GRAFIK_XPIXEL/(12+TXTABSTANDX)
_L1:	cp  r16, r17		;maximale Spaltenzahl ueberschritten?
	brcs _L2		;nein-->
	mov r16, r17
	dec r16			;ja: auf letzte Spalte setzen
_L2:	sts txt_spalte, r16
	ret

backspace:
	push r18
	lds r18, txt_spalte
	tst r18
	breq _L1		;provi. Backspace auf aktuelle Zeile begrenzt
	dec r18
	sts txt_spalte, r18
	ldi r16, ' '
	rcall text_zeichnen
	sts txt_spalte, r18
_L1:	pop r18
	ret

piepston_starten:
	;; noch machen
	ret

hexdigit:			;untere 4 Bits von r16 in eine Hex-Zahl (0...A) wandeln
	push r18
	andi r16, 0x0F
	cpi r16, 10
	brcs he_L1
	ldi r18, 7
	add r16, r18
he_L1:	ldi r18, '0'
	add r16, r18
	pop r18
	ret

zeichengroesse_setzen:		;r16=neue Fontbreite, r17=neue Fonthoehe, r18=alte Fontbreite
	sts fontbreite, r16
	sts fonthoehe, r17
	lds r16, txt_zeile
	lds r17, txt_spalte
	cpi r18, 6
	breq _L2
	lsl r16			;Wechsel von gross nach klein
	sts txt_zeile, r16	;etwa doppelt so viele Zeilen mit kleiner Schrift
	lsl r17
	sts txt_spalte, r17	;etwa doppelt so viele Spalten mit kleiner Schrift
	ret
_L2:	lsr r16			;Wechsel von klein nach gross
	sts txt_zeile, r16	;etwa halb so viele Zeilen mit grosser Schrift
	lsr r17
	sts txt_spalte, r17	;etwa halb so viele Spalten mit grosser Schrift
	ret

;-----------------------------------------------------------------------------
; Grafik-Funktionen

punkt_setzen:			;Punkt an Grafik-Cursor mit Farbe r16 setzen, zerstoert: r16-r17, r0-r1
	push XL
	push XH
	push r18
	cpi r16, 0x10
	brcc _L0
	swap r16		;Farbe in oberes Halbbyte verschieben
_L0:	andi r16, 0xF0
	ldi XL, low(bildspeicher)
	ldi XH, high(bildspeicher)
	ldi r17, GRAFIK_XPIXEL/2
	lds r18, ycursorL	;ycursorH nicht gebraucht, da Anzahl Zeilen kleiner 256
	mul r18, r17
	add XL, r0
	adc XH, r1
	lds r18, xcursorL	;xcursorH auch nicht gebraucht
	lsr r18			;r18=xcursor/2, Cy=Rest
	brcs _L1
	add XL, r18
	adc XH, zero
	ld r18, X		;aktuelles Pixel lesen
	andi r18, 0x0F		;zweites Pixel unveraendert
	rjmp _L2
_L1:	add XL, r18
	adc XH, zero
	ld r18, X		;aktuelles Pixel lesen
	andi r18, 0xF0		;erstes Pixel unveraendert
	swap r16
_L2:	or  r18, r16		;aktuelles Pixel setzen
	st X, r18
	pop r18
	pop XH
	pop XL
	ret

punkt_setzen2:		;Schnellere Variante: Punkt mit Vordergundfarbe setzen, zerstoert: X, r16-r17, r0-r1
	ldi XL, low(bildspeicher)
	ldi XH, high(bildspeicher)
	ldi r17, GRAFIK_XPIXEL/2
	lds r16, ycursorL	;ycursorH nicht gebraucht, da Anzahl Zeilen kleiner 256
	mul r16, r17
	add XL, r0
	adc XH, r1
	lds r16, xcursorL	;xcursorH auch nicht gebraucht
	lsr r16
	brcs _L1
	add XL, r16
	adc XH, zero
	ld r16, X		;aktuelles Pixel lesen
	andi r16, 0x0F		;zweites Pixel unveraendert
	or  r16, textfarbe	;erstes Pixel setzen
	st X, r16
	ret
_L1:	add XL, r16
	adc XH, zero
	ld r16, X		;aktuelles Pixel lesen
	andi r16, 0xF0		;erstes Pixel unveraendert
	mov r17, textfarbe
	swap r17
	or  r16, r17		;zeites Pixel setzen
	st X, r16
	ret

waagrechte_linie_zeichnen:	;Linie von xcursorL,ycursorL nach xcursor2L zeichnen
	push r18		;sollte noch optimiert werden
	push r19
	push r20
	ldi r20, 1
	lds r18, xcursorL
	lds r19, xcursor2L
	cp r18, r19		;Zielpunkt groesser?
	brcs _L2		;ja-->
	neg r20			;nein: r20 = -1
	rjmp _L2
_L1:	add r18, r20
	sts xcursorL, r18
_L2:	rcall punkt_setzen2
	cp r18, r19
	brne _L1
	pop r20
	pop r19
	pop r18
	ret

linie_zeichnen:			;Linie von xcursorL,ycursorL bis xcursor2L,ycursor2L zeichnen, mit textfarbe
	push r18		;zerstoert: r16-r17, r0-r1
	push r19
	push r20
	push XL
	push XH
	ldi r20, 1
	rcall punkt_setzen2	;Startpunkt setzen
	lds r16, xcursorL
	lds r17, xcursor2L
	lds r18, ycursorL
	lds r19, ycursor2L
	cp r16, r17		;xcursor mit xcursor2 vergleichen
	breq senkrechte_linie
	cp r18, r19		;ycursor mit ycursor2 vergleichen
	brne schraege_linie
waagrechte_linie:
	lds r18, xcursorL
	lds r19, xcursor2L
	cp r18, r19		;Zielpunkt groesser?
	brcs _L1		;ja-->
	neg r20			;nein: r20 = -1
_L1:	cp r18, r19
	breq endpunkt
	add r18, r20
	sts xcursorL, r18
	rcall punkt_setzen2
	rjmp _L1
senkrechte_linie:
	lds r18, ycursorL
	lds r19, ycursor2L
	cp r18, r19		;Zielpunkt groesser?
	brcs _L1		;ja-->
	neg r20			;nein: r20 = -1
_L1:	cp r18, r19
	breq endpunkt
	add r18, r20
	sts ycursorL, r18
	rcall punkt_setzen2
	rjmp _L1
endpunkt:
;	lds r16, xcursor2L
;	sts xcursorL, r16
;	lds r16, ycursor2L
;	sts ycursorL, r16
;	rcall punkt_setzen2	;Endpunkt setzen  //test schon gesetzt?
	pop XH
	pop XL
	pop r20
	pop r19
	pop r18
	ret
schraege_linie:	
	push r12
	push r13
	push r14
	push r21
	push r28
	push r29
	push r30
	push r31
	ldi r21, 1
	sub r16, r17
	brcc _L1
	neg r16			;r16 = dx = Absolutwert xcursor-xcursor2
_L1:	sub r18, r19
	brcc _L2
	neg r18			;r18 = dy = Absolutwert ycursor-ycursor2
_L2:
	mul r16, r18		;dx*dy
	movw r28, r0		;r29:r28=Max
	cp r16, r18		;x-Diff. groesser?
	brcc xgroesser		;ja-->
ygroesser:
	mov r19, r18		;r19=dy
	mov r18, r16		;r18=dx
	movw r16, r28		;r17:r16=Max
	rcall mulu8		;dx*Max --> r18:r17:r16
	rcall divu24u8		;r18:r17:r16 /= r19
	movw r30, r16		;r31:r30=Schrittweite
	lds r18, ycursorL
	lds r19, ycursor2L
	cp r18, r19		;Zielpunkt y groesser?
	brcs _L1		;ja-->
	neg r21			;nein: r21 = -1
_L1:	lds r14, xcursorL
	lds r17, xcursor2L
	cp r14, r17		;Zielpunkt x groesser?
	brcs _L2		;ja-->
	neg r20			;nein: r20 = -1
_L2:	movw r12, r28		;r13:r12 = xZaehler = Max/2
	lsr r13
	ror r12
_L3:	cp r18, r19		;Zielpunkt erreicht?
	breq popr31		;ja-->
	add r18, r21		;y erhoehen
	sts ycursorL, r18
	add r12, r30
	adc r13, r31		;xZaehler += Schrittweite
	cp  r12, r28
	cpc r13, r29		;xZaehler >= Max ?
	brcs _L4		;nein->
	sub r12, r28
	sbc r13, r29		;ja: subtrahieren
	add r14, r20		;x erhoehen
	sts xcursorL, r14
_L4:	rcall punkt_setzen2
	rjmp _L3
xgroesser:
	mov r19, r16		;r19=dx, r18=dy
	movw r16, r28		;r17:r16=Max
	rcall mulu8		;dy*Max --> r18:r17:r16
	rcall divu24u8		;r18:r17:r16 /= r19
	movw r30, r16		;r31:r30=Schrittweite
	lds r14, ycursorL
	lds r17, ycursor2L
	cp r14, r17		;Zielpunkt y groesser?
	brcs _L1		;ja-->
	neg r21			;nein: r21 = -1
_L1:	lds r18, xcursorL
	lds r19, xcursor2L
	cp r18, r19		;Zielpunkt x groesser?
	brcs _L2		;ja-->
	neg r20			;nein: r20 = -1
_L2:	movw r12, r28		;r13:r12 = yZaehler = Max/2
	lsr r13
	ror r12
_L3:	cp r18, r19		;Zielpunkt erreicht?
	breq popr31		;ja-->
	add r18, r20		;x erhoehen
	sts xcursorL, r18
	add r12, r30
	adc r13, r31		;yZaehler += Schrittweite
	cp  r12, r28
	cpc r13, r29		;yZaehler >= Max ?
	brcs _L4		;nein->
	sub r12, r28
	sbc r13, r29		;ja: subtrahieren
	add r14, r21		;y erhoehen
	sts ycursorL, r14
_L4:	rcall punkt_setzen2
	rjmp _L3
popr31:	pop r31
	pop r30
	pop r29
	pop r28
	pop r21
	pop r14
	pop r13
	pop r12
	rjmp endpunkt

viereck_zeichnen:	;r17=Fuellflag, zerstoert: r16-r17, r0-r1
	push r18
	push r19
	push r20
	push r21
	push r17		;Fuellflag
	lds r18, xcursorL	;x1
	lds r19, ycursorL	;y1 Punkt links oben
	lds r20, xcursor2L	;x2
	lds r21, ycursor2L	;y2 Punkt rechts unten
	sts xcursor2L, r18
	rcall linie_zeichnen	;senkrechte Linie links
	sts xcursorL, r20
	sts ycursorL, r19
	sts xcursor2L, r20
	rcall linie_zeichnen	;senkrechte Linie rechts
	sts xcursorL, r18
	sts ycursorL, r19
	sts ycursor2L, r19
	rcall linie_zeichnen	;waagrechte Linie oben
	sts xcursorL, r18
	sts ycursorL, r21
	sts ycursor2L, r21
	rcall linie_zeichnen	;waagrechte Linie unten
	pop r17
	tst r17			;Fuellflag gesetzt?
	breq _ret		;nein--> fertig
	cp r19, r21		;y2==y1 ?
	breq _ret		;ja--> fertig
_L1:	ldi r17, 1
	cp r19, r21		;y1<y2 ?
	brcs _L2		;ja--> r17 = +1
	neg r17			;nein: r17 = -1
_L2:	add r19, r17		;y1 erhoehen
	cp r19, r21		;y2 erreicht?
	breq _ret		;ja--> fertig
	sts xcursorL, r18
	sts ycursorL, r19
	sts ycursor2L, r19
	rcall linie_zeichnen	;waagrechte Linie
	rjmp _L1
_ret:	sts xcursorL, r20
	sts ycursorL, r21	;Cursor auf Endposition setzen
	pop r21
	pop r20
	pop r19
	pop r18
	ret

kreis_zeichnen:		;r17=Fuellflag, zerstoert: r16-r17, r0-r1
	push r12
	push r13
	push r14
	push r18
	push r19
	push r20
	push r21
	push XL
	push XH
	push r28
	push r29
	push r30
	push r31
.def aneu=r12
.def avorher=r13
	clr avorher
	mov r14, r17		;r14=Fuellflag
	lds r18, xcursorL	;x0
	lds r19, ycursorL	;y0 Kreismittelpunkt
	lds r20, xcursor2L	;xd
	lds r21, ycursor2L	;yd Durchmesser in x- und y-Richtung
	cpi r20, 2		;Auf minimalen Durchmesser pruefen
	brcs _klein2
	cpi r21, 2
	brcc _start
_klein1:
	lsr r20			;xr=xd/2
	mov r16, r18
	sub r16, r20
	sts xcursorL, r16
	mov r16, r18
	add r16, r20
	sts xcursor2L, r16
	rcall waagrechte_linie_zeichnen
	rjmp _fertig
_klein2:
	cpi r21, 2
	brcs _klein3
	lsr r21		;yr=yd/2
	mov r16, r19
	sub r16, r21
	sts ycursorL, r16
	mov r16, r19
	add r16, r21
	sts ycursor2L, r16
	sts xcursor2L, r18
	rcall linie_zeichnen
	sts ycursorL, r19
	rjmp _fertig
_klein3:
	rcall punkt_setzen2
	rjmp _fertig
_start:
;	rcall punkt_setzen2	;//test: Mittelpunkt
	ldi r28, 1		;r28=2*i, i=0.5
	mov r29, r21
	lsr r29			;ry abgerundet
	brcc _L1		;Cy gesetzt? nein-->
	ldi r28, 2		;ja: i=1 statt 0.5
_L1:	mov r16, r19		;y0
	sub r16, r29		;r16 = Startpunkt = y0 - ry(abgerundet)
	sts ycursorL, r16
	rcall ay_ausrechnen	;ay=sqrt(yd*i-i*i) ;r28=2*i, r21=yd, Resultat=r16
	mul r16, r20		;r1:r0=ay*xd
	clr r17
	mov r16, r21		;yDurchmesser
	lsr r16			;yd/2 addieren fuer korrekte Rundung bei anschliessendem Dividieren
	add r16, r0
	adc r17, r1		;r17:r16 = ay*xd+yd/2
	rcall divu16u8		;r17:r16 / r21 --> r12, a = (ay*xd+yd/2)/yd (mit korrekter Rundung)
	mov r30, r18
	mov r31, r18
	sub r30, r12		;r30=xmitte-a
	add r31, r12		;r31=xmitte+a
	sts xcursorL, r30
	tst r14			;Fuellflag gesetzt?
	brne _fuellen		;ja-->
	cp aneu, avorher
	breq _p1
	tst avorher
	breq _p1b
	inc avorher
	cp aneu, avorher
	breq _p1
	mov r16, r18
	sub r16, avorher
	sts xcursor2L, r16
	rcall waagrechte_linie_zeichnen
	mov r16, r18
	add r16, avorher
	sts xcursorL, r16
_p1b:	sts xcursor2L, r31
	rcall waagrechte_linie_zeichnen
	rjmp _p1a
_p1:	rcall punkt_setzen2
	sts xcursorL, r31
	rcall punkt_setzen2
_p1a:	mov r16, r19		;y0
	add r16, r29		;addieren fuer zweite Kreishaelfte
	sts ycursorL, r16
	sts xcursorL, r30
	cp aneu, avorher
	breq _p2
	tst avorher
	breq _p2b
	mov r16, r18
	sub r16, avorher
	sts xcursor2L, r16
	rcall waagrechte_linie_zeichnen
	mov r16, r18
	add r16, avorher
	sts xcursorL, r16
_p2b:	sts xcursor2L, r31
	rcall waagrechte_linie_zeichnen
	rjmp _p2a
_p2:	rcall punkt_setzen2
	sts xcursorL, r31
	rcall punkt_setzen2
_p2a:	mov avorher, aneu
	rjmp _L2
_fuellen:
	sts xcursor2L, r31
	rcall waagrechte_linie_zeichnen
	mov r16, r19		;y0
	add r16, r29		;addieren fuer zweite Kreishaelfte
	sts ycursorL, r16
	sts xcursorL, r30
	rcall waagrechte_linie_zeichnen
_L2:	dec r29			;naechste Linie
	breq _fastfertig
	subi r28, -2		;i erhoehen
	rjmp _L1
_fastfertig:
	mov r29, r20		;xd
	lsr r29			;rx=xd/2
	mov r16, r18
	sub r16, r29
	sts xcursorL, r16
	sts ycursorL, r19	;Mittellinie zeichnen
	add r29, r18
	tst r14			;Fuellflag gesetzt?
	brne _fuellenmitte	;ja-->
	rcall punkt_setzen2
	sts xcursorL, r29
	rcall punkt_setzen2
	rjmp _fertig
_fuellenmitte:	
	sts xcursor2L, r29
	rcall waagrechte_linie_zeichnen
_fertig:
	sts xcursorL, r18
;	sts ycursorL, r19	;Cursor wieder auf Mittelpunkt setzen
	pop r31
	pop r30
	pop r29
	pop r28
	pop XH
	pop XL
	pop r21
	pop r20
	pop r19
	pop r18
	pop r14
	pop r13
	pop r12
	ret

ay_ausrechnen:		;ay=sqrt(yd*i-i*i) ;r28=2*i, r21=yd, Resultat=r16, zerstoert: r17, r0-r1
	mul r21, r28
	lsr r1
	ror r0
	movw r16, r0	;r17:r16=yd*i
	mul r28, r28
	lsr r1
	ror r0
	lsr r1
	ror r0		;(2i)*(2i)/4 = i*i
	sub r16, r0
	sbc r17, r1
	rjmp sqrt_16bit

;-----------------------------------------------------------------------------
; Quadratwurzel
#ifdef WURZEL_ALTE_VERSION
sqrt_16bit:			;Wurzel von r17:r16 berechnen, Resultat: r16, zerstoert: r0-r1, r17
	tst r17			;Oberes Byte leer?
	breq sqrt_8bit		;ja--> Wurzel aus 8-Bit-Zahl
	push r18		;Heron-Verfahren fuer Wurzel(y): Schaetzwert a, b=y/a, neues a=(a+b)/2
	push r19		;Hier: y-Minimalwert=256, y-Maximalwert=65535 
	push r20		;      beim Maximalwert wird das Resultat 255 sein, also abgerundeter Wert
	ldi r18, 16		;Startwert 16
_L1:	mov r20, r18		;r20 = a
	rcall divur20		;r17:r16 / r20 --> r19:r18, r19:r18 = b
	add r18, r20
	adc r19, zero		;a+b
	lsr r19
	brne _L2
	ror r18			;(a+b)/2
	rjmp _L3
_L2:	ldi r18, 255		;Maximalwert
_L3:	cp r18, r20		;neues a==vorheriges a?
	breq _fertig
	dec r20
	cp r18, r20		;neues a nur um 1 verschieden zu verherigem?
	brne _L1		;nein-->
_fertig:
	mov r16, r18
	pop r20
	pop r19
	pop r18
	ret

sqrt_16bit_variante0:		;Wurzel von r17:r16 berechnen, Resultat: r16, zerstoert: r0-r1
	push r20		;sehr kurz, aber langsam und ungenau
	ldi r20, 255
_L1:	mul r20, r20
	cp  r16, r0
	cpc r17, r1
	brcc _fertig
	dec r20
	brne _L1
_fertig:	;; Resultat ist eventuell abgerundet
	mov r16, r20
	pop r20
	ret			;maximal 2052 Takte
#endif

#ifdef WURZELTEST
sqrt_16bit_variante1:		;Wurzel von r17:r16 berechnen, Resultat: r16, zerstoert: r0-r1
	push r18		;kurz aber langsam
	push r19
	push r20
	ldi r20, 255
	mul r20, r20
	sub r0, r16
	sbc r1, r17
	breq _fertig
	brcs _fertig
_L1:	movw r18, r0		;Differenz in r19:r18 speichern
	dec r20
_L2:	mul r20, r20
	sub r0, r16
	sbc r1, r17
	breq _fertig
	brcc _L1
	movw r16, r0		;Vorherige Differenz in r17:r16 speichern
	com r16			;Wert negieren mit Zweiercomplement:
	com r17			;Bits umkehren,
	subi r16, -1		;dann 1 addieren
	sbci r17, -1
	cp  r18, r16		;vorheriger Wert kleinere Abweichung?
	cpc r19, r17
	brcc _fertig		;nein-->
	inc r20			;ja: vorheriger Wert nehmen
_fertig:mov r16, r20
	pop r20
	pop r19
	pop r18
	ret			;maximal 2326 Takte
#endif

sqrt8_tabelle:
	.db 0,1,1,2,2,2,2,3,3,3,3,3,3,4,4,4 ;0...15
	.db 4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,6 ;16...31
	.db 6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7 ;32...47
	.db 7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8 ;48...63
	.db 8,8,8,8,8,8,8,8,8,9,9,9,9,9,9,9 ;64...79
	.db 9,9,9,9,9,9,9,9,9,9,9,10,10,10,10,10 ;80...95
	.db 10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,11 ;96...111
	.db 11,11,11,11,11,11,11,11,11,11,11,11,11,11,11,11 ;112...127
	.db 11,11,11,11,11,12,12,12,12,12,12,12,12,12,12,12 ;128...143
	.db 12,12,12,12,12,12,12,12,12,12,12,12,12,13,13,13 ;144...159
	.db 13,13,13,13,13,13,13,13,13,13,13,13,13,13,13,13 ;160...163
	.db 13,13,13,13,13,13,13,14,14,14,14,14,14,14,14,14 ;176...191
	.db 14,14,14,14,14,14,14,14,14,14,14,14,14,14,14,14 ;192...207
	.db 14,14,14,15,15,15,15,15,15,15,15,15,15,15,15,15 ;208...223
	.db 15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15 ;224...239
	.db 15,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16 ;240...255

#ifdef WURZELTEST
;; Variante2: kompliziert und trotzdem langsam
sqrt_16bit_variante2:		;Wurzel von r17:r16 berechnen, Resultat: r16, zerstoert: r0-r1, (r5=zero)
	tst r17			;Oberes Byte leer?
	breq sqrt_8bit		;ja--> Wurzel aus 8-Bit-Zahl
	push r18		;Heron-Verfahren fuer Wurzel(y): Schaetzwert a, b=y/a, neues a=(a+b)/2
	push r19		;Hier: y-Minimalwert=256, y-Maximalwert=65535 
	push r20		;      beim Maximalwert wird das Resultat 255 sein, also abgerundeter Wert
	ldi r18, high(64771)
	cpi r16, low(64771)	;x>=64771
	cpc r17, r18
	brcc _maxwert		;ja: Ergebnis=Maximalwert=255
	ldi r18, 16		;Startwert 16
	mov r19, r17
	rjmp _L0
_maxwert:
	ldi r20, 255
	rjmp _fertig
_max_startwert:
	ldi r18, 255
	rjmp _L1
_startwert:
	lsl r18			;besserer Startwert
	brcs _max_startwert
	lsr r19
_L0:	lsr r19
	brne _startwert
_L1:	mov r20, r18		;r20 = a
	rcall divur20		;r17:r16 / r20 --> r19:r18, r19:r18 = b
	lsl r0
	cp  r20, r0		;Rest>a/2 ? ja: Cy setzen und somit aufrunden
	adc r18, r20		;a+b + Cy fuer Rundung
	adc r19, zero		;a+b
	lsr r19
	brne _L2
	ror r18			;(a+b)/2
	rjmp _L3
_L2:	ldi r18, 255		;Maximalwert
_L3:	cp r18, r20		;neues a==vorheriges a?
	breq _fastfertig
	dec r20
	cp r18, r20		;neues a nur um 1 verschieden zu verherigem?
	brne _L1		;nein-->
_fastfertig:
	mul r20, r20		;a*a
	movw r18, r16
	sub r18, r0
	sbc r19, r1		;r19:r18 = x-a*a, a*a<x ?
	breq _fertig		;nein-->
	brcs _fertig		;nein-->
	inc r20			;r20=a+1
	mul r20, r20		;(a+1)*(a+1)
	sub r0, r16
	sbc r1, r17		;(a+1)*(a+1)-x
	cp  r0, r18
	cpc r1, r19		;(a+1)*(a+1)-x < x-a*a ?
	brcs _fertig		;ja: Resultat=a+1
	dec r20			;nein: Resultat=a
_fertig:
	mov r16, r20
	pop r20
	pop r19
	pop r18
	ret
#endif

sqrt_8bit:			;Wurzel von r16 berechnen, Resultat: r16
	push ZL
	push ZH
	ldi ZL, low(sqrt8_tabelle<<1)
	ldi ZH, high(sqrt8_tabelle<<1)
	add ZL, r16
	adc ZH, zero
	lpm r16, Z
	pop ZH
	pop ZL
	ret

#ifdef WURZELTEST
sqrt_16bit_variante3:		;Wurzel von r17:r16 berechnen, Resultat: r16, zerstoert: r0-r1
	tst r17			;Oberes Byte leer?
	breq sqrt_8bit		;ja--> Wurzel aus 8-Bit-Zahl
	push r18
	push r19
	push r20
	ldi r20, 0x80		;a=0x80=Startwert
	cpi r17, 0x40		;x>=a*a ?
	brcc _start		;ja--> starten
	ldi r18, 0x40		;0x4000 entspricht a*a
_L0:	lsr r20			;besserer Startwert berechnen
	lsr r18
	lsr r18
	cp  r17, r18		;x>=a*a ?
	brcs _L0		;nein-->
_start:	mov r19, r20		;mask setzen
_L1:	lsr r19
	breq _fastfertig
_L2:	mov r18, r20
	or  r20, r19		;Bit setzen
	mul r20, r20
	cp  r16, r0
	cpc r17, r1		;a*a>=x ?
	breq _fertig		;gleich --> schon fertig
	brcc _L1		;kleiner -->
	mov r20, r18		;groesser: Bit wieder loeschen
	lsr r19
	brne _L2
_fastfertig:
	cpi r20, 255
	breq _fertig
	mul r20, r20		;a*a
	movw r18, r16
	sub r18, r0
	sbc r19, r1		;r19:r18 = x-a*a
	inc r20			;r20=a+1
	mul r20, r20		;(a+1)*(a+1)
	sub r0, r16
	sbc r1, r17		;(a+1)*(a+1)-x
	cp  r0, r18
	cpc r1, r19		;(a+1)*(a+1)-x < x-a*a ?
	brcs _fertig		;ja: Resultat=a+1
	dec r20			;nein: Resultat=a
_fertig:
	mov r16, r20
	pop r20
	pop r19
	pop r18
	ret			;max 128 Takte
#endif

;; variante4:
sqrt_16bit:			;Wurzel von r17:r16 berechnen, Resultat: r16, zerstoert: r0-r1
	tst r17			;Oberes Byte leer?
	breq sqrt_8bit		;ja--> Wurzel aus 8-Bit-Zahl
	push r18
	push r19
	push r20
	ldi r20, 0x40		;a=Startwert
	cpi r17, 0x10		;x>=a*a ?
	brcc _s1		;ja-->
	ldi r20, 0x10
	cpi r17, 0x04		;x>=0x20*0x20 ?
	brcs _start		;nein--> Startwert 0x10
	ldi r20, 0x20
	rjmp _start
_s1:	cpi r17, 0x40
	brcs _start
	ldi r20, 0x80
_start:	mov r19, r20		;mask setzen
_L1:	lsr r19
	breq _fastfertig
_L2:	mov r18, r20
	or  r20, r19		;Bit setzen
	mul r20, r20
	cp  r0, r16
	cpc r1, r17		;a*a<=x ?
	brcs _L1		;kleiner-->
	breq _fertig		;gleich --> exakter Wert gefunden
	mov r20, r18		;groesser: Bit wieder loeschen
	lsr r19
	brne _L2
_fastfertig:
	cpi r20, 255
	breq _fertig
	mul r20, r20		;a*a
	movw r18, r16
	sub r18, r0
	sbc r19, r1		;r19:r18 = x-a*a
	inc r20			;r20=a+1
	mul r20, r20		;(a+1)*(a+1)
	sub r0, r16
	sbc r1, r17		;(a+1)*(a+1)-x
	cp  r0, r18
	cpc r1, r19		;(a+1)*(a+1)-x < x-a*a ?
	brcs _fertig		;ja: Resultat=a+1
	dec r20			;nein: Resultat=a
_fertig:
	mov r16, r20
	pop r20
	pop r19
	pop r18
	ret			;max 127 Takte

#ifdef WURZELTEST
teste_wurzelprogramm:		;r16-r17 zerstoert
	push r0
	push r1
	push r18
	push r19
	ldi r18, 0
	ldi r19, 0		;r19:r18=Startwert=0
_L1:	movw r16, r18
	rcall sqrt_16bit	;Wurzel berechnen
	rcall uart_putc		;Resultat ueber Serielle Schnittstelle schicken
	subi r18, -1
	sbci r19, -1		;naechster Wert
	brne _L1
	pop r19
	pop r18
	pop r1
	pop r0
	ret

wurzel_text:
	.db "Wurzeltest ",0
teste_wurzel_varianten:		;r16-r17 zerstoert
	push r0
	push r1
	push r18
	push r19
	push r20
	push r21
	clr r16
	rcall neuezeile
	clr r16
	rcall neuespalte
	ldi ZL, low(wurzel_text<<1)
	ldi ZH, high(wurzel_text<<1)
	rcall text_darstellen
	ldi r16, 1
	rcall neuezeile
	clr r16
	rcall neuespalte
	ldi r18, 0
	ldi r19, 0		;r19:r18=Startwert=0
	ldi r21, 1		;naechster anzuzeigender Wert: 1*256=256
_L1:	movw r16, r18
	rcall sqrt_16bit	;Wurzel berechnen
	mov r20, r16
	movw r16, r18
	rcall sqrt_16bit_variante3	;Wurzel anders berechnen
	cpse r16, r20			;Resultate gleich?
	rcall wurzel_fehler		;nein: Fehlermeldung
	cp  r19, r21		;Wert anzeigen?
	brne _L2		;nein-->
	rcall wurzel_ergebnis_anzeigen
	subi r21, -50		;naechster Wert: 50*256=12800 mehr (also 13056, 25856, 38656, ... 64000)
_L2:	
;	rcall uart_putc		;Resultat ueber Serielle Schnittstelle schicken
	subi r18, -1
	sbci r19, -1		;naechster Wert
	brne _L1
	pop r21
	pop r20
	pop r19
	pop r18
	pop r1
	pop r0
	ret

wurzel_ergebnis_anzeigen:
	push r16
	push r17
	rcall print_r19r18	;aktuelle Zahl anzeigen
	ldi r16, ' '
	rcall text_zeichnen
	mov r16, r20
	rcall print_r16		;Ergebnis Berechnung
	ldi r16, ' '
	rcall text_zeichnen
	lds r16, txt_zeile
	inc r16
	rcall neuezeile
	clr r16
	rcall neuespalte
	pop r17
	pop r16
	ret

wurzel_fehler:
	push r16
	push r17
	push r21
	mov r21, r16
	rcall print_r19r18	;aktuelle Zahl anzeigen
	ldi r16, ' '
	rcall text_zeichnen
	mov r16, r20
	rcall print_r16		;Ergebnis von erster Berechnung
	ldi r16, ' '
	rcall text_zeichnen
	mov r16, r21
	rcall print_r16		;Ergebnis von 2. Berechnung
	lds r16, txt_zeile
	inc r16
	rcall neuezeile
	clr r16
	rcall neuespalte
	pop r21
	pop r17
	pop r16
	ret
#endif ;//WURZELTEST

;-----------------------------------------------------------------------------
; Genaue Wartefunktionen:
; tickswait wartet genau soviele Takte wie in r16 steht, mindestens 18
; usecwait wartet genau soviele Microsekunden wie in r16 steht
;-----------------------------------------------------------------------------
tickswait:			;r16 = Anzahl zu wartende Takte (inklusive ldi und rcall und ret)
	cpi r16, 18		;Minimale Anzahl Ticks: bei weniger stimmts nicht
	brcs ti_ret
	subi r16, 14
	lsr r16
	brcs ti_L1
ti_L1:	lsr r16
	brcc ti_L3
	adiw r24, 0		;statt 2 mal nop
ti_L2:	nop
ti_L3:	dec r16
	brne ti_L2
ti_ret:	ret

tickswait17: nop
tickswait16: nop
tickswait15: nop
tickswait14: nop
tickswait13: nop
tickswait12: nop
tickswait11: nop
tickswait10: nop
tickswait9:  nop
tickswait8:  nop
tickswait7:  ret		;rcall und ret brauchen zusammen 7 Takte


#if (F_CPU==20000000)
us_L1:	adiw r24, 0
	adiw r24, 0
	adiw r24, 0
	adiw r24, 0
usecwait:			;r16 = Anzahl Microsekunden warten (bei 20MHz) (inklusive ldi und rcall und ret)
	adiw r24, 0
	adiw r24, 0
	adiw r24, 0
	adiw r24, 0
	nop
	dec r16
	brne us_L1
	nop
	ret
#endif

;-----------------------------------------------------------------------------
; divmodu16u8
;  16Bit vorzeichenlose Zahl dividieren durch 8Bit vorzeichenlosen Teiler
; Eingabe: r13:r12 = Zahl (16Bit), r18 = Teiler (8Bit)
; Ausgabe: r13:r12 = Resultat, r18 = Rest
; Speicherverbrauch: 34 Byte
; Anzahl Takte: 177 - 193
;  Wenn Teiler 0 ist wird das Resultat 0xFFFF sein
;-----------------------------------------------------------------------------
divmodu16u8:
	push r16
	push r17
	mov r16, r18
	clr r18
	ldi r17, 16
di_L1:	lsl r12
	rol r13
	rol r18
	brcs di_L3
	cp r18, r16
	brcs di_L2
di_L3:	sub r18, r16
	inc r12
di_L2:	dec r17
	brne di_L1
	pop r17
	pop r16
	ret

;-----------------------------------------------------------------------------
; divu16u8
divu16u8:			;r17:r16 / r21 --> r12
	push r19
	clr r12
	ldi r19, 16
_L1:	lsl r16
	rol r17
	rol r12
	brcs _L3
	cp r12, r21
	brcs _L2
_L3:	sub r12, r21
	inc r16
_L2:	dec r19
	brne _L1
	mov r12, r16
	pop r19
	ret

;-----------------------------------------------------------------------------
; divur20  Auf Geschwindigkeit Optimierte Variante fuer Wurzelberechnung, Minimaler Teiler 16
; Anzahl Takte: 140 bis 152
divur20:		;r17:r16 / r20 --> r19:r18, unveraendert: r17:r16, zerstoert: r0-r1
	ldi r18, 12		;Es muessen noch 12 Bits in der Schlaufe behandelt werden
	mov r1, r18		;r1 = Schlaufenzaehler
	ldi r18, 0x0F		;Erste 4 Bits sofort schieben, da minimaler Teiler=16 ist
	mov r19, r17
	swap r19
	mov r0, r19
	and r0, r18		;Oberste 4 Bits von r17:r16 ins r0 geschoben
	andi r19, 0xF0		;Naechste 4 Bits in r19 nach links geschoben
	swap r16
	and r18, r16		;obere 4 Bits von r16 in untere 4 Bits von r19 kopieren
	or  r19, r18
	mov r18, r16
	andi r18, 0xF0		;unterste 4 Bits in r18 nach links geschoben
	swap r16		;r16 unveraendert
_L1:	lsl r18
	rol r19
	rol r0
	brcs _L3
	cp r0, r20
	brcs _L2
_L3:	sub r0, r20
	inc r18			;Resultat-Bit setzen
_L2:	dec r1
	brne _L1
	ret

;-----------------------------------------------------------------------------
; divu24u8
;  24Bit vorzeichenlose Zahl dividieren durch 8Bit vorzeichenlosen Teiler
divu24u8:	; r18:r17:r16 /= r19
	push r20
	push r21
	ldi r21, 24		;24 Bits rotieren
	clr r20
_L1:	lsl r16
	rol r17
	rol r18
	rol r20			;Bits ins r20 schieben
	brcs _L3
	cp r20, r19
	brcs _L2
_L3:	sub r20, r19
	inc r16			;Resultat += 1
_L2:	dec r21
	brne _L1
;	mov r19, r20		;Falls Rest gebraucht wird
	pop r21
	pop r20
	ret

;-----------------------------------------------------------------------------
; mulu16
;  Vorzeichenlose Multiplikation zweiter 16Bit-Zahlen
; Eingabe: r17:r16, r19:r18
; Ausgabe: r19:r18:r17:r16
mulu16:			;r19:r18:r17:r16 = r17:r16 * r19:r18
	push r12	;Abkuerzung fuer Kommentare:
	push r13	; AB=r17:r16, BC=r19:r18, EFGH=Ergebnis
	push r26
	push r27
	mul r17, r19	;A*C
	movw r26, r0	; EFGH = AB*CD --> EF=A*C GH=B*D EFG+=A*D+B*C
			; r27:r26 = EF=A*C
	mul r16, r18	;B*D
	movw r12, r0	; r13:r12 = GH=B*D
	mul r17, r18	;A*D
	clr r17
	add r13, r0	; EFG+=A*D
	adc r26, r1
	adc r27, r17
	mul r16, r19	;B*C
	add r13, r0	; EFG+=B*C
	adc r26, r1
	adc r27, r17
	movw r16, r12
	movw r18, r26
	pop r27
	pop r26
	pop r13
	pop r12
	ret

;-----------------------------------------------------------------------------
; mulu8
;  Vorzeichenlose Multiplikation einer 16Bit-Zahl mit einer 8Bit-Zahl
; Eingabe: r17:r16, r18  (AB*C --> FGH)
; Resultat: r18:r17:r16, zerstoert: r0,r1
mulu8:	mul r16, r18	;B*C
	mov r16, r0	;r1:r16 = B*C
	push r1
	mul r17, r18	;r1:r0 = A*C
	pop r17		;r17:r16 = B*C
	ldi r18, 0	; F=0
	add r17, r0	; FG+=A*C
	adc r18, r1
	ret
mulu8r0:	;r1:r0*r16 --> r1:r0, r17 zerstoert
	push r18
	mov r18, r0
	mul r1, r16
	mov r17, r0
	mul r18, r16
	add r1, r17
	pop r18
	ret

;-----------------------------------------------------------------------------
;; Uhr: Zeit seit dem Einschalten
uhr_reset:
	sts uhr_ticks64, zero
	sts uhr_millisecL, zero
	sts uhr_millisecH, zero
	sts uhr_sec, zero
	sts uhr_min, zero
	sts uhr_std, zero
	sts uhr_tage, zero
	ret

uhr_update64:			;Zeit alle 64us aktualisieren, r16 zerstoert
	push r24		;Benoetigte Anzahl Takte: 61 inklusive rcall und ret
	push r25		;braucht immer exakt gleich viele Takte
	lds r24, uhr_ticks64
	subi r24, -8		;statt 64 addieren um auf 1000 zu zaehlen, 8 addieren und auf 125 zaehlen
	subi r24, 125		;Vergleich und Subtraktion von 125
	brcs _L1		;springe wenn Wert noch kleiner 125
	sts uhr_ticks64, r24
	lds r24, uhr_millisecL
	lds r25, uhr_millisecH
	adiw r24, 1
	subi r24, low(1000)
	sbci r25, high(1000)	;Vergleich und Subtratktion von 1000
	brcs _L2		;springe wenn Wert noch kleiner 1000
	sts uhr_millisecL, r24
	sts uhr_millisecH, r25
	lds r24, uhr_sec
	inc r24
	subi r24, 60
	brcs _L3
	sts uhr_sec, r24
	lds r24, uhr_min
	inc r24
	subi r24, 60
	brcs _L4
	sts uhr_min, r24
	lds r24, uhr_std
	inc r24
	subi r24, 24
	brcs _L5
	sts uhr_std, r24
	lds r24, uhr_tage
	inc r24
	sts uhr_tage, r24
_ret:	pop r25
	pop r24
	ret
_L1:	subi r24, -125		;Subtraktion rueckgaengig machen
	sts uhr_ticks64, r24
	ticksw [35]
	rjmp _ret
_L2:	subi r24, low(-1000)
	sbci r25, high(-1000)	;Subtraktion rueckgaengig machen
	sts uhr_millisecL, r24
	sts uhr_millisecH, r25
	ticksw [21]
	rjmp _ret
_L3:	subi r24, -60		;Subtraktion rueckgaengig machen
	sts uhr_sec, r24
	ticksw [15]
	rjmp _ret
_L4:	subi r24, -60		;Subtraktion rueckgaengig machen
	sts uhr_min, r24
	ticksw [8]
	rjmp _ret
_L5:	subi r24, -24		;Subtraktion rueckgaengig machen
	sts uhr_std, r24
	nop
	rjmp _ret

uhr_update64_schnell:		;Schnelle Varainte braucht meistens weniger als 61 Takte
	push r24
	lds r24, uhr_ticks64
	subi r24, -8		;statt 64 addieren um auf 1000 zu zaehlen, 8 addieren und auf 125 zaehlen
	subi r24, 125		;Vergleich und Subtraktion von 125
	brcs _L1		;springe wenn Wert noch kleiner 125
	sts uhr_ticks64, r24
	push r25
	lds r24, uhr_millisecL
	lds r25, uhr_millisecH
	adiw r24, 1
	subi r24, low(1000)
	sbci r25, high(1000)	;Vergleich und Subtratktion von 1000
	brcs _L2		;springe wenn Wert noch kleiner 1000
	sts uhr_millisecL, r24
	sts uhr_millisecH, r25
	lds r24, uhr_sec
	inc r24
	subi r24, 60
	brcs _L3
	sts uhr_sec, r24
	lds r24, uhr_min
	inc r24
	subi r24, 60
	brcs _L4
	sts uhr_min, r24
	lds r24, uhr_std
	inc r24
	subi r24, 24
	brcs _L5
	sts uhr_std, r24
	lds r24, uhr_tage
	inc r24
	sts uhr_tage, r24
_ret:	pop r25
	pop r24
	ret
_L1:	subi r24, -125		;Subtraktion rueckgaengig machen
	sts uhr_ticks64, r24
	pop r24
	ret
_L2:	subi r24, low(-1000)
	sbci r25, high(-1000)	;Subtraktion rueckgaengig machen
	sts uhr_millisecL, r24
	sts uhr_millisecH, r25
	rjmp _ret
_L3:	subi r24, -60		;Subtraktion rueckgaengig machen
	sts uhr_sec, r24
	rjmp _ret
_L4:	subi r24, -60		;Subtraktion rueckgaengig machen
	sts uhr_min, r24
	rjmp _ret
_L5:	subi r24, -24		;Subtraktion rueckgaengig machen
	sts uhr_std, r24
	rjmp _ret

;-----------------------------------------------------------------------------
; RS232-Teil:
;.equ UBRR_VAL = (F_CPU+BAUDRATE*8)/(BAUDRATE*16)-1  ;clever runden
.equ UBRR_VAL = (F_CPU+BAUDRATE*4)/(BAUDRATE*8)-1  ;clever runden, Wert fur mit Doublespeed
.equ BAUD_REAL  = (F_CPU/(8*(UBRR_VAL+1)))     	   ; Reale Baudrate
.equ BAUD_ERROR = ((BAUD_REAL*1000)/BAUDRATE-1000) ; Fehler in Promille

.if ((BAUD_ERROR>10) || (BAUD_ERROR<-10))       ; max. +/-10 Promille Fehler
  .warning "Systematischer Fehler der Baudrate groesser 1%"
.endif 

.if ((BAUD_ERROR>20) || (BAUD_ERROR<-20))       ; max. +/-20 Promille Fehler
  .error "Systematischer Fehler der Baudrate groesser 2% und damit zu hoch!"
.endif 

uart_init:			; Initialisierung fuer Asynchron 8N1
	clr r16
	sts jread, r16
	sts jwrite, r16
	ldi r16, LOW(UBRR_VAL)
	ldi r17, HIGH(UBRR_VAL)
	ldi r18, (1<<U2X0)		 ;fuer Doublespeed
;	ldi r19, (1<<RXEN0) | (0<<TXEN0) ;nur Empfangen, ohne Interrupts
	ldi r19, (1<<RXEN0) | (1<<TXEN0) ;Empfangen und Senden, ohne Interrupts
	sts UBRR0H, r17
	sts UBRR0L, r16
	sts UCSR0A, r18
	sts UCSR0B, r19
	ldi r20, (1<<UCSZ01)|(1<<UCSZ00)
	sts UCSR0C, r20
	ret

uart_check:		    ; Pruefen ob ein Zeichen empfangen wurde, und wenn ja im Puffer speichern
			    ; braucht 45 Takte, r16 zerstoert
	push r17
	push r18
	push XL
	push XH
	ldi XL, low(serbuffer)
	ldi XH, high(serbuffer)
	lds r17, jwrite
	lds r18, jread
	add XL, r17
	adc XH, zero
	lds r16, UCSR0A
	andi r16, (1<<RXC0)	;neues Zeichen empfangen?
	breq ua_L1		;nein->
	lds r16, UDR0		;ja: einlesen
	inc r17
	andi r17, SERBUFFERSIZE-1
	cp r17, r18		;ist Puffer voll?
	breq ua_L2		;ja-> Zeichen ignorieren
	st X, r16		;nein: Zeichen im Puffer speichern
	sts jwrite, r17
ua_ret:	pop XH
	pop XL
	pop r18
	pop r17
	ret
ua_L1:
	adiw r24, 0		;statt 2 mal nop
	adiw r24, 0		;statt 2 mal nop
	adiw r24, 0		;statt 2 mal nop
ua_L2:	nop
	rjmp ua_ret

uart_putc:
	lds r17, UCSR0A
	andi r17, (1<<UDRE0)	;Sendepuffer bereit?
	breq uart_putc		;nein--> warten
	sts UDR0, r16
	ret

;-----------------------------------------------------------------------------
; Text-Teil

.macro naechstes_zeichen
	.error "missing parameters"
.endm
.macro naechstes_zeichen_i_i	;Textcursor erhoehen
	lds r16, txt_spalte
	inc r16
	cpi r16, GRAFIK_XPIXEL/(@0+TXTABSTANDX)
	brcs L2
	lds r16, txt_zeile
	inc r16
	cpi r16, GRAFIK_ZEILEN/(@1+TXTABSTANDY)
	brcs L1
	clr r16
L1:	sts txt_zeile, r16
	clr r16
L2:	sts txt_spalte, r16
.endm

naechste_zeile:		;Textcursor auf naechste Zeile auf Spalte 0 setzen
	clr r16
	sts txt_spalte, r16
	ldi r17, GRAFIK_ZEILEN/(8+TXTABSTANDY)	
	lds r16, fontbreite
	cpi r16, 12
	brne _L1
	ldi r17, GRAFIK_ZEILEN/(16+TXTABSTANDY)	
_L1:	lds r16, txt_zeile
	inc r16
	cp  r16, r17
	brcs _L2
	clr r16
_L2:	sts txt_zeile, r16
	ret
	
text_print:		;Zeichen r16 zeichnen mit Beruecksichtigung von Zeilentrenner
	cpi r16, LF
	breq naechste_zeile
text_zeichnen:		;Zeichen r16 an Position txt_zeile, txt_spalte zeichnen
	lds r17, fontbreite
	cpi r17, 12
	brne text_zeichnen_6x8
	rjmp text_zeichnen_12x16
text_zeichnen_6x8:		;Zeichen r16 an Position txt_zeile, txt_spalte zeichnen
	push XL			;r0-r1, r16-r17 zerstoert
	push XH
	push ZL
	push ZH
	push r18
	push r19
	push r20
	ldi XL, low(bildspeicher)
	ldi XH, high(bildspeicher)
	mov r18, r16
	lds r16, txt_zeile
	ldi r17, GRAFIK_XPIXEL/2 	;txt_zeile * Anzahl_Bytes_pro_Zeile
	mul r16, r17			;r1:r0 = Resultat
	ldi r16, 8+TXTABSTANDY		;Multiplizieren mit Zeichenhoehe+Abstand
	rcall mulu8r0			;r1:r0*r16 --> r1:r0
	add XL, r0
	adc XH, r1
	lds r16, txt_spalte
	ldi r17, (6+TXTABSTANDX+1)/2
	mul r16, r17		;txt_spalte * Zeichenbreite/2  (2 Pixel pro Byte)
	add XL, r0
	adc XH, r1
	ldi ZL, low(font6x8<<1)
	ldi ZH, high(font6x8<<1) ;Zeiger auf Font-Tabelle
	ldi r20, 8		;8 Bytes pro Zeichen
	mul r18, r20
	add ZL, r0
	adc ZH, r1		;Zeiger auf gewuenschtes Zeichen
_L1:	lpm r16, Z+
	ldi r19, 6/2		;6 Pixel bearbeiten, jeweils 2 aufs mal
_L2:	mov r17, hintergrundfarbe
	lsl r16			;aktuelles Bit ins Cy schieben
	brcc _L3
	mov r17, textfarbe	;bei gesetztem Cy Vordergrundfarbe waehlen
_L3:	mov r18, hintergrundfarbe
	lsl r16			;naechstes Bit ins Cy schieben
	brcc _L4
	mov r18, textfarbe	;bei gesetztem Cy Vordergrundfarbe waehlen
_L4:	swap r18
	cpi r17, 0x80		;Farbe==durchsichtig?
	brne _L4a
	ld  r17, X		;ja: aktuelle Farbe uebernehmen
	andi r17, 0xF0
_L4a:	cpi r18, 0x08		;Zweites Pixel durchsichtig?
	brne _L4b
	ld  r18, X		;ja: aktuelle Farbe uebernehmen
	andi r18, 0x0F
_L4b:	or  r17, r18		;die beiden Pixel kombinieren
	st  X+, r17
	dec r19
	brne _L2
#if TXTABSTANDX>0
	cpi hintergrundfarbe, 0x80 ;Farbe durchsichtig?
	breq _L5		   ;ja--> nichts zu tun
 #if TXTABSTANDX==1
	ld r18, X
	andi r18, 0x0F		;2. Pixel unveraendert
 #else
	mov r18, hintergrundfarbe
	swap r18		  ;2. Pixel auf Hintergrundfarbe setzen
 #endif
	or  r18, hintergrundfarbe ;1. Pixel auf Hintergrundfarbe setzen
	st  X, r18
 #if TXTABSTANDX>2
	adiw X, 1
	st  X, r18		;naechste 2 Pixel auch auf Hintergrundfarbe setzen
  #if TXTABSTANDX>4
	adiw X, 1
	st  X, r18		;naechste 2 Pixel auch auf Hintergrundfarbe setzen
	sbiw X, 1
  #endif
	sbiw X, 1
 #endif
_L5:	
#endif
	subi XL, low(-((GRAFIK_XPIXEL-6)/2)) ;Addition fuer naechste Grafikzeile
	sbci XH, high(-((GRAFIK_XPIXEL-6)/2)) ;Addition fuer naechste Grafikzeile
	dec r20
	brne _L1
	naechstes_zeichen [6,8]
	pop r20
	pop r19
	pop r18
	pop ZH
	pop ZL
	pop XH
	pop XL
	ret

text_zeichnen_12x16:		;Zeichen r16 an Position txt_zeile, txt_spalte zeichnen
	push XL			;r0-r1, r16-r17 zerstoert
	push XH
	push ZL
	push ZH
	push r14
	push r18
	push r19
	push r20
	ldi XL, low(bildspeicher)
	ldi XH, high(bildspeicher)
	mov r18, r16
	lds r16, txt_zeile
	ldi r17, GRAFIK_XPIXEL/2 	;txt_zeile * Anzahl_Bytes_pro_Zeile
	mul r16, r17			;r1:r0 = Resultat
	ldi r16, 16+TXTABSTANDY		;Multiplizieren mit Zeichenhoehe+Abstand
	rcall mulu8r0			;r1:r0*r16 --> r1:r0
	add XL, r0
	adc XH, r1
	lds r16, txt_spalte
	ldi r17, (12+TXTABSTANDX+1)/2
	mul r16, r17		;txt_spalte * Zeichenbreite/2  (2 Pixel pro Byte)
	add XL, r0
	adc XH, r1
	ldi ZL, low(font12x16<<1)
	ldi ZH, high(font12x16<<1) ;Zeiger auf Font-Tabelle
	ldi r20, 32		;32 Bytes pro Zeichen
	mul r18, r20
	add ZL, r0
	adc ZH, r1		;Zeiger auf gewuenschtes Zeichen
	ldi r20, 16		;16 mal 2 Bytes bearbeiten
_L1:	lpm r14, Z+
	lpm r16, Z+
	ldi r19, 12/2		;12 Pixel bearbeiten, jeweils 2 aufs mal
_L2:	mov r17, hintergrundfarbe
	lsl r16			;aktuelles Bit ins Cy schieben
	rol r14			;aktuelles Bit ins Cy schieben
	brcc _L3
	mov r17, textfarbe	;bei gesetztem Cy Vordergrundfarbe waehlen
_L3:	mov r18, hintergrundfarbe
	lsl r16			;naechstes Bit ins Cy schieben
	rol r14			;naechstes Bit ins Cy schieben
	brcc _L4
	mov r18, textfarbe	;bei gesetztem Cy Vordergrundfarbe waehlen
_L4:	swap r18
	cpi r17, 0x80		;Farbe==durchsichtig?
	brne _L4a
	ld  r17, X		;ja: aktuelle Farbe uebernehmen
	andi r17, 0xF0
_L4a:	cpi r18, 0x08		;Zweites Pixel durchsichtig?
	brne _L4b
	ld  r18, X		;ja: aktuelle Farbe uebernehmen
	andi r18, 0x0F
_L4b:	or  r17, r18		;die beiden Pixel kombinieren
	st  X+, r17
	dec r19
	brne _L2
#if TXTABSTANDX>0
	cpi hintergrundfarbe, 0x80 ;Farbe durchsichtig?
	breq _L5		   ;ja--> nichts zu tun
 #if TXTABSTANDX==1
	ld r18, X
	andi r18, 0x0F		;2. Pixel unveraendert
 #else
	mov r18, hintergrundfarbe
	swap r18		  ;2. Pixel auf Hintergrundfarbe setzen
 #endif
	or  r18, hintergrundfarbe ;1. Pixel auf Hintergrundfarbe setzen
	st  X, r18
_L5:	
#endif
	subi XL, low(-((GRAFIK_XPIXEL-12)/2)) ;Addition fuer naechste Grafikzeile
	sbci XH, high(-((GRAFIK_XPIXEL-12)/2)) ;Addition fuer naechste Grafikzeile
	dec r20
	brne _L1
	naechstes_zeichen [12,16]
	pop r20
	pop r19
	pop r18
	pop r14
	pop ZH
	pop ZL
	pop XH
	pop XL
	ret

zahl2stellig:			;Zahl in r16 als Text 2-stellig
	push r12
	push r13
	push r17
	push r18
	ldi r18, 10
	clr r13
	mov r12, r16
	rcall divmodu16u8
	ldi r16, '0'
	add r16, r12
	rcall text_zeichnen
	ldi r16, '0'
	add r16, r18
	rcall text_zeichnen
	pop r18
	pop r17
	pop r13
	pop r12
	ret

print_r16:			;Zahl in r16 als Text (0...255)
	push r12
	push r13
	push r17
	push r18
	mov r18, r16
	cpi r18, 10
	brcs _L4
	cpi r18, 100
	brcs _L3
	cpi r18, 200
	brcs _L1
	subi r18, 200
	ldi r16, '2'
	rjmp _L2
_L1:	subi r18, 100
	ldi r16, '1'
_L2:	rcall text_zeichnen
_L3:	mov r16, r18
	ldi r18, 10
	clr r13
	mov r12, r16
	rcall divmodu16u8
	ldi r16, '0'
	add r16, r12
	rcall text_zeichnen
_L4:	ldi r16, '0'
	add r16, r18
	rcall text_zeichnen
	pop r18
	pop r17
	pop r13
	pop r12
	ret

print_r19r18:			;Zahl in r19:r18 als Text (max. 5-stellig, 0...65535), zerstoert: r16, r0-r1
	mov r16, r18
	tst r19
	breq print_r16
	push r12
	push r13
	push r17
	push r18
	push r19
	ldi r17, high(1000)
	cpi r18, low(1000)
	cpc r19, r17
	brcs _L3
	movw r12, r18
	lsr r13			;durch 1000 dividieren:
	ror r12			;zuerst durch 4
	lsr r13
	ror r12
	push r18
	ldi r18, 250		;dann durch 250
	rcall divmodu16u8	;r13:r12 / r18 --> r13:r12, r18=Rest
	pop r18
	mov r16, r12
	rcall print_r16
	ldi r16, 250
	mul r12, r16
	lsl r0
	rol r1
	lsl r0
	rol r1
	sub r18, r0
	sbc r19, r1
_L3:	movw r12, r18
	ldi r18, 100
	rcall divmodu16u8	;r13:r12 / r18 --> r13:r12, r18=Rest
	ldi r16, '0'
	add r16, r12
	rcall text_zeichnen
	mov r12, r18
	clr r13
	ldi r18, 10
	rcall divmodu16u8	;r13:r12 / r18 --> r13:r12, r18=Rest
	ldi r16, '0'
	add r16, r12
	rcall text_zeichnen
	ldi r16, '0'
	add r16, r18
	rcall text_zeichnen
	pop r19
	pop r18
	pop r17
	pop r13
	pop r12
	ret
